@@ -298,35 +298,44 @@ volume:
 """
 
 import time
+from typing import Any
+from typing import Dict
+from typing import List
+from typing import Optional
+from typing import Tuple
 
 from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
 
 from ansible_collections.amazon.aws.plugins.module_utils.arn import is_outpost_arn
-from ansible_collections.amazon.aws.plugins.module_utils.botocore import is_boto3_error_code
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import AnsibleEC2Error
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import attach_volume as attach_ec2_volume
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import create_volume as create_ec2_volume
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import delete_volume as delete_ec2_volume
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import describe_ec2_tags
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import describe_instances
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import describe_volumes
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import detach_volume as detach_ec2_volume
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import ensure_ec2_tags
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import modify_instance_attribute
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import modify_volume
 from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
-from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
 from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_list_to_ansible_dict
 from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_specifications
 from ansible_collections.amazon.aws.plugins.module_utils.transformation import ansible_dict_to_boto3_filter_list
-
-try:
-    import botocore
-except ImportError:
-    pass  # Taken care of by AnsibleAWSModule
+from ansible_collections.amazon.aws.plugins.module_utils.waiters import wait_for_resource_state
 
 
-def get_instance(module, ec2_conn, instance_id=None):
+def get_instance(module: AnsibleAWSModule, ec2_conn, instance_id: Optional[str] = None) -> Optional[Dict[str, Any]]:
     instance = None
     if not instance_id:
         return instance
 
     try:
-        reservation_response = ec2_conn.describe_instances(aws_retry=True, InstanceIds=[instance_id])
-        instance = camel_dict_to_snake_dict(reservation_response["Reservations"][0]["Instances"][0])
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, msg=f"Error while getting instance_id with id {instance}")
+        reservation_response = describe_instances(ec2_conn, InstanceIds=[instance_id])
+        if reservation_response:
+            instance = camel_dict_to_snake_dict(reservation_response[0]["Instances"][0])
+    except AnsibleEC2Error as e:
+        module.fail_json_aws(e, msg=f"Error while getting instance_id with id {instance_id}")
 
     return instance
 
@@ -354,23 +363,18 @@ def get_volume(module, ec2_conn, vol_id=None, fail_on_not_found=True):
         find_params["Filters"] = ansible_dict_to_boto3_filter_list({"availability-zone": zone})
 
     try:
-        paginator = ec2_conn.get_paginator("describe_volumes")
-        vols_response = paginator.paginate(**find_params)
-        vols = list(vols_response)[0].get("Volumes")
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        if is_boto3_error_code("InvalidVolume.NotFound"):
-            module.exit_json(msg=f"Volume {vol_id} does not exist", changed=False)
+        vols = describe_volumes(ec2_conn, **find_params)
+        if not vols:
+            if fail_on_not_found and vol_id:
+                msg = f"Could not find volume with id: {vol_id}"
+                if name:
+                    msg += f" and name: {name}"
+                module.fail_json(msg=msg)
+            else:
+                return None
+    except AnsibleEC2Error as e:
         module.fail_json_aws(e, msg=f"Error while getting EBS volumes with the parameters {find_params}")
 
-    if not vols:
-        if fail_on_not_found and vol_id:
-            msg = f"Could not find volume with id: {vol_id}"
-            if name:
-                msg += f" and name: {name}"
-            module.fail_json(msg=msg)
-        else:
-            return None
-
     if len(vols) > 1:
         module.fail_json(
             msg=f"Found more than one volume in zone (if specified) with name: {name}",
@@ -380,23 +384,18 @@ def get_volume(module, ec2_conn, vol_id=None, fail_on_not_found=True):
     return vol
 
 
-def delete_volume(module, ec2_conn, volume_id=None):
+def delete_volume(module: AnsibleAWSModule, ec2_conn, volume_id: Optional[str] = None) -> bool:
     changed = False
     if volume_id:
         try:
-            ec2_conn.delete_volume(aws_retry=True, VolumeId=volume_id)
-            changed = True
-        except is_boto3_error_code("InvalidVolume.NotFound"):
-            module.exit_json(changed=False)
-        except (
-            botocore.exceptions.ClientError,
-            botocore.exceptions.BotoCoreError,
-        ) as e:  # pylint: disable=duplicate-except
+            changed = delete_ec2_volume(ec2_conn, volume_id)
+        except AnsibleEC2Error as e:
             module.fail_json_aws(e, msg="Error while deleting volume")
+        wait_for_resource_state(ec2_conn, module, "volume_deleted", VolumeIds=[volume_id])
     return changed
 
 
-def update_volume(module, ec2_conn, volume):
+def update_volume(module: AnsibleAWSModule, ec2_conn, volume: Dict[str, Any]) -> Tuple[Dict[str, Any], bool]:
     changed = False
     req_obj = {"VolumeId": volume["volume_id"]}
 
@@ -466,18 +465,21 @@ def update_volume(module, ec2_conn, volume):
         if changed:
             if module.check_mode:
                 module.exit_json(changed=True, msg="Would have updated volume if not in check mode.")
-            response = ec2_conn.modify_volume(**req_obj)
+            try:
+                response = modify_volume(ec2_conn, **req_obj)
+            except AnsibleEC2Error as e:
+                module.fail_json_aws(e, msg="Error while modifying volume")
 
-            volume["size"] = response.get("VolumeModification").get("TargetSize")
-            volume["volume_type"] = response.get("VolumeModification").get("TargetVolumeType")
-            volume["iops"] = response.get("VolumeModification").get("TargetIops")
-            volume["multi_attach_enabled"] = response.get("VolumeModification").get("TargetMultiAttachEnabled")
-            volume["throughput"] = response.get("VolumeModification").get("TargetThroughput")
+            volume["size"] = response.get("TargetSize")
+            volume["volume_type"] = response.get("TargetVolumeType")
+            volume["iops"] = response.get("TargetIops")
+            volume["multi_attach_enabled"] = response.get("TargetMultiAttachEnabled")
+            volume["throughput"] = response.get("TargetThroughput")
 
     return volume, changed
 
 
-def create_volume(module, ec2_conn, zone):
+def create_volume(module: AnsibleAWSModule, ec2_conn, zone: str) -> Tuple[Dict[str, Any], bool]:
     changed = False
     iops = module.params.get("iops")
     encrypted = module.params.get("encrypted")
@@ -497,60 +499,59 @@ def create_volume(module, ec2_conn, zone):
         module.exit_json(changed=True, msg="Would have created a volume if not in check mode.")
 
     if volume is None:
+        changed = True
+        additional_params = dict()
+
+        if volume_size:
+            additional_params["Size"] = int(volume_size)
+
+        if kms_key_id:
+            additional_params["KmsKeyId"] = kms_key_id
+
+        if snapshot:
+            additional_params["SnapshotId"] = snapshot
+
+        if iops:
+            additional_params["Iops"] = int(iops)
+
+        # Use the default value if any iops has been specified when volume_type=gp3
+        if volume_type == "gp3" and not iops:
+            additional_params["Iops"] = 3000
+
+        if throughput:
+            additional_params["Throughput"] = int(throughput)
+
+        if multi_attach:
+            additional_params["MultiAttachEnabled"] = True
+
+        if outpost_arn:
+            if is_outpost_arn(outpost_arn):
+                additional_params["OutpostArn"] = outpost_arn
+            else:
+                module.fail_json("OutpostArn does not match the pattern specified in API specifications.")
+
+        if name:
+            tags["Name"] = name
+
+        if tags:
+            additional_params["TagSpecifications"] = boto3_tag_specifications(tags, types=["volume"])
+
         try:
-            changed = True
-            additional_params = dict()
-
-            if volume_size:
-                additional_params["Size"] = int(volume_size)
-
-            if kms_key_id:
-                additional_params["KmsKeyId"] = kms_key_id
-
-            if snapshot:
-                additional_params["SnapshotId"] = snapshot
-
-            if iops:
-                additional_params["Iops"] = int(iops)
-
-            # Use the default value if any iops has been specified when volume_type=gp3
-            if volume_type == "gp3" and not iops:
-                additional_params["Iops"] = 3000
-
-            if throughput:
-                additional_params["Throughput"] = int(throughput)
-
-            if multi_attach:
-                additional_params["MultiAttachEnabled"] = True
-
-            if outpost_arn:
-                if is_outpost_arn(outpost_arn):
-                    additional_params["OutpostArn"] = outpost_arn
-                else:
-                    module.fail_json("OutpostArn does not match the pattern specified in API specifications.")
-
-            if name:
-                tags["Name"] = name
-
-            if tags:
-                additional_params["TagSpecifications"] = boto3_tag_specifications(tags, types=["volume"])
-
-            create_vol_response = ec2_conn.create_volume(
-                aws_retry=True, AvailabilityZone=zone, Encrypted=encrypted, VolumeType=volume_type, **additional_params
+            create_vol_response = create_ec2_volume(
+                ec2_conn, AvailabilityZone=zone, Encrypted=encrypted, VolumeType=volume_type, **additional_params
             )
-
-            waiter = ec2_conn.get_waiter("volume_available")
-            waiter.wait(
-                VolumeIds=[create_vol_response["VolumeId"]],
-            )
-            volume = get_volume(module, ec2_conn, vol_id=create_vol_response["VolumeId"])
-        except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
+        except AnsibleEC2Error as e:
             module.fail_json_aws(e, msg="Error while creating EBS volume")
 
+        wait_for_resource_state(ec2_conn, module, "volume_available", VolumeIds=[create_vol_response["VolumeId"]])
+        volume = get_volume(module, ec2_conn, vol_id=create_vol_response["VolumeId"])
+
     return volume, changed
 
 
-def attach_volume(module, ec2_conn, volume_dict, instance_dict, device_name):
+def attach_volume(
+    module: AnsibleAWSModule, ec2_conn, volume_dict: Dict[str, Any], instance_dict: Dict[str, Any], device_name: str
+) -> Tuple[Dict[str, Any], bool]:
     changed = False
 
     # If device_name isn't set, make a choice based on best practices here:
@@ -565,7 +566,9 @@ def attach_volume(module, ec2_conn, volume_dict, instance_dict, device_name):
             if attachment_data[0].get("status") in ["attached", "attaching"]:
                 instance_id = attachment_data[0].get("instance_id", "None")
                 module.exit_json(
-                    changed=False, msg=f"IN CHECK MODE - volume already attached to instance: {instance_id}."
+                    changed=False,
+                    msg=f"IN CHECK MODE - volume already attached to instance: {instance_id}.",
+                    volume=volume_dict,
                 )
         if not volume_dict["multi_attach_enabled"]:
             # volumes without MultiAttach Enabled can be attached to 1 instance only
@@ -580,20 +583,15 @@ def attach_volume(module, ec2_conn, volume_dict, instance_dict, device_name):
     try:
         if module.check_mode:
             module.exit_json(changed=True, msg="Would have attached volume if not in check mode.")
-        attach_response = ec2_conn.attach_volume(
-            aws_retry=True,
-            Device=device_name,
-            InstanceId=instance_dict["instance_id"],
-            VolumeId=volume_dict["volume_id"],
+        attach_response = attach_ec2_volume(
+            ec2_conn, device=device_name, instance_id=instance_dict["instance_id"], volume_id=volume_dict["volume_id"]
         )
-
-        waiter = ec2_conn.get_waiter("volume_in_use")
-        waiter.wait(VolumeIds=[attach_response["VolumeId"]])
-        changed = True
-
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
+    except AnsibleEC2Error as e:
         module.fail_json_aws(e, msg="Error while attaching EBS volume")
 
+    wait_for_resource_state(ec2_conn, module, "volume_in_use", VolumeIds=[attach_response["VolumeId"]])
+    changed = True
+
     modify_dot_attribute(module, ec2_conn, instance_dict, device_name)
 
     volume = get_volume(module, ec2_conn, vol_id=volume_dict["volume_id"])
@@ -601,7 +599,7 @@ def attach_volume(module, ec2_conn, volume_dict, instance_dict, device_name):
     return volume, changed
 
 
-def modify_dot_attribute(module, ec2_conn, instance_dict, device_name):
+def modify_dot_attribute(module: AnsibleAWSModule, ec2_conn, instance_dict: Dict[str, Any], device_name: str) -> bool:
     """Modify delete_on_termination attribute"""
 
     delete_on_termination = module.params.get("delete_on_termination")
@@ -622,15 +620,15 @@ def modify_dot_attribute(module, ec2_conn, instance_dict, device_name):
 
     if delete_on_termination != mapped_block_device["ebs"].get("delete_on_termination"):
         try:
-            ec2_conn.modify_instance_attribute(
-                aws_retry=True,
-                InstanceId=instance_dict["instance_id"],
+            modify_instance_attribute(
+                ec2_conn,
+                instance_id=instance_dict["instance_id"],
                 BlockDeviceMappings=[
                     {"DeviceName": device_name, "Ebs": {"DeleteOnTermination": delete_on_termination}}
                 ],
             )
             changed = True
-        except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
+        except AnsibleEC2Error as e:
             module.fail_json_aws(
                 e, msg=f"Error while modifying Block Device Mapping of instance {instance_dict['instance_id']}"
             )
@@ -638,7 +636,7 @@ def modify_dot_attribute(module, ec2_conn, instance_dict, device_name):
     return changed
 
 
-def get_attachment_data(volume_dict, wanted_state=None):
+def get_attachment_data(volume_dict: Dict[str, Any], wanted_state: Optional[str] = None) -> List[Dict[str, Any]]:
     attachment_data = []
     if not volume_dict:
         return attachment_data
@@ -661,7 +659,7 @@ def get_attachment_data(volume_dict, wanted_state=None):
     return attachment_data
 
 
-def detach_volume(module, ec2_conn, volume_dict):
+def detach_volume(module: AnsibleAWSModule, ec2_conn, volume_dict: Dict[str, Any]) -> Tuple[Dict[str, Any], bool]:
     changed = False
 
     attachment_data = get_attachment_data(volume_dict, wanted_state="attached")
@@ -669,18 +667,19 @@ def detach_volume(module, ec2_conn, volume_dict):
     for attachment in attachment_data:
         if module.check_mode:
             module.exit_json(changed=True, msg="Would have detached volume if not in check mode.")
-        ec2_conn.detach_volume(aws_retry=True, InstanceId=attachment["instance_id"], VolumeId=volume_dict["volume_id"])
-        waiter = ec2_conn.get_waiter("volume_available")
-        waiter.wait(
-            VolumeIds=[volume_dict["volume_id"]],
-        )
+        try:
+            detach_ec2_volume(ec2_conn, volume_id=volume_dict["volume_id"], InstanceId=attachment["instance_id"])
+        except AnsibleEC2Error as e:
+            module.fail_json_aws(e, msg="Error while detaching volume")
+
+        wait_for_resource_state(ec2_conn, module, "volume_available", VolumeIds=[volume_dict["volume_id"]])
         changed = True
 
     volume_dict = get_volume(module, ec2_conn, vol_id=volume_dict["volume_id"])
     return volume_dict, changed
 
 
-def get_volume_info(module, volume, tags=None):
+def get_volume_info(volume: Dict[str, Any], tags: Optional[Dict[str, str]] = None) -> Dict[str, Any]:
     if not tags:
         tags = boto3_tag_list_to_ansible_dict(volume.get("tags"))
     attachment_data = get_attachment_data(volume)
@@ -704,7 +703,9 @@ def get_volume_info(module, volume, tags=None):
     return volume_info
 
 
-def get_mapped_block_device(instance_dict=None, device_name=None):
+def get_mapped_block_device(
+    instance_dict: Optional[Dict[str, Any]] = None, device_name: Optional[str] = None
+) -> Optional[str]:
     mapped_block_device = None
     if not instance_dict:
         return mapped_block_device
@@ -719,7 +720,9 @@ def get_mapped_block_device(instance_dict=None, device_name=None):
     return mapped_block_device
 
 
-def ensure_tags(module, connection, res_id, res_type, tags, purge_tags):
+def ensure_tags(
+    module: AnsibleAWSModule, connection, res_id: str, res_type: str, tags: Dict[str, Any], purge_tags: bool
+) -> Tuple[Dict[str, Any], bool]:
     if module.check_mode:
         return {}, True
     changed = ensure_ec2_tags(connection, module, res_id, res_type, tags, purge_tags, ["InvalidVolume.NotFound"])
@@ -728,6 +731,111 @@ def ensure_tags(module, connection, res_id, res_type, tags, purge_tags):
     return final_tags, changed
 
 
+def ensure_present(ec2_conn, module: AnsibleAWSModule, volume: Optional[Dict[str, Any]]) -> None:
+    instance = module.params.get("instance")
+    name = module.params.get("name")
+    zone = module.params.get("zone")
+    device_name = module.params.get("device_name")
+    tags = module.params.get("tags")
+
+    # Ensure we have the zone or can get the zone
+    if instance is None and zone is None:
+        module.fail_json(msg="You must specify either instance or zone")
+
+    # Set volume detach flag
+    if instance == "None" or instance == "":
+        instance = None
+        detach_vol_flag = True
+    else:
+        detach_vol_flag = False
+
+    # Here we need to get the zone info for the instance. This covers situation where
+    # instance is specified but zone isn't.
+    # Useful for playbooks chaining instance launch with volume create + attach and where the
+    # zone doesn't matter to the user.
+    inst = None
+    if instance:
+        inst = get_instance(module, ec2_conn, instance_id=instance)
+        zone = inst["placement"]["availability_zone"]
+
+        # Use platform attribute to guess whether the instance is Windows or Linux
+        if device_name is None:
+            if inst.get("platform", "") == "Windows":
+                device_name = "/dev/xvdf"
+            else:
+                device_name = "/dev/sdf"
+
+        # Check if there is a volume already mounted there.
+        mapped_device = get_mapped_block_device(instance_dict=inst, device_name=device_name)
+        if mapped_device:
+            other_volume_mapped = False
+            if volume:
+                if volume["volume_id"] != mapped_device["ebs"]["volume_id"]:
+                    other_volume_mapped = True
+            else:
+                # No volume found so this is another volume
+                other_volume_mapped = True
+
+            if other_volume_mapped:
+                module.exit_json(
+                    msg=f"Volume mapping for {device_name} already exists on instance {instance}",
+                    volume_id=mapped_device["ebs"]["volume_id"],
+                    found_volume=volume,
+                    device=device_name,
+                    changed=False,
+                )
+    final_tags = None
+    tags_changed = False
+    if volume:
+        volume, changed = update_volume(module, ec2_conn, volume)
+        if name:
+            if not tags:
+                tags = boto3_tag_list_to_ansible_dict(volume.get("tags"))
+            tags["Name"] = name
+        final_tags, tags_changed = ensure_tags(
+            module, ec2_conn, volume["volume_id"], "volume", tags, module.params.get("purge_tags")
+        )
+    else:
+        volume, changed = create_volume(module, ec2_conn, zone=zone)
+
+    if detach_vol_flag:
+        volume, attach_changed = detach_volume(module, ec2_conn, volume_dict=volume)
+    elif inst is not None:
+        volume, attach_changed = attach_volume(
+            module, ec2_conn, volume_dict=volume, instance_dict=inst, device_name=device_name
+        )
+    else:
+        attach_changed = False
+
+    # Add device, volume_id and volume_type parameters separately to maintain backward compatibility
+    volume_info = get_volume_info(volume, tags=final_tags)
+
+    if tags_changed or attach_changed:
+        changed = True
+
+    module.exit_json(
+        changed=changed,
+        volume=volume_info,
+        device=device_name,
+        volume_id=volume_info["id"],
+        volume_type=volume_info["type"],
+    )
+
+
+def ensure_absent(ec2_conn, module: AnsibleAWSModule, volume: Optional[Dict[str, Any]]) -> None:
+    name = module.params.get("name")
+    param_id = module.params.get("id")
+    changed = False
+    if not name and not param_id:
+        module.fail_json("A volume name or id is required for deletion")
+    if volume and volume.get("state") not in ("deleting", "deleted"):
+        if module.check_mode:
+            module.exit_json(changed=True, msg="Would have deleted volume if not in check mode.")
+        detach_volume(module, ec2_conn, volume_dict=volume)
+        changed = delete_volume(module, ec2_conn, volume_id=volume["volume_id"])
+    module.exit_json(changed=changed)
+
+
 def main():
     argument_spec = dict(
         instance=dict(),
@@ -762,29 +870,14 @@ def main():
 
     param_id = module.params.get("id")
     name = module.params.get("name")
-    instance = module.params.get("instance")
     volume_size = module.params.get("volume_size")
-    device_name = module.params.get("device_name")
-    zone = module.params.get("zone")
     snapshot = module.params.get("snapshot")
     state = module.params.get("state")
-    tags = module.params.get("tags")
     iops = module.params.get("iops")
     volume_type = module.params.get("volume_type")
     throughput = module.params.get("throughput")
     multi_attach = module.params.get("multi_attach")
 
-    # Ensure we have the zone or can get the zone
-    if instance is None and zone is None and state == "present":
-        module.fail_json(msg="You must specify either instance or zone")
-
-    # Set volume detach flag
-    if instance == "None" or instance == "":
-        instance = None
-        detach_vol_flag = True
-    else:
-        detach_vol_flag = False
-
     if iops:
         if volume_type in ("gp2", "st1", "sc1", "standard"):
             module.fail_json(msg="IOPS is not supported for gp2, st1, sc1, or standard volumes.")
@@ -804,16 +897,7 @@ def main():
     if multi_attach is True and volume_type not in ("io1", "io2"):
         module.fail_json(msg="multi_attach is only supported for io1 and io2 volumes.")
 
-    # Set changed flag
-    changed = False
-
-    ec2_conn = module.client("ec2", AWSRetry.jittered_backoff())
-
-    # Here we need to get the zone info for the instance. This covers situation where
-    # instance is specified but zone isn't.
-    # Useful for playbooks chaining instance launch with volume create + attach and where the
-    # zone doesn't matter to the user.
-    inst = None
+    ec2_conn = module.client("ec2")
 
     # Delaying the checks until after the instance check allows us to get volume ids for existing volumes
     # without needing to pass an unused volume_size
@@ -823,82 +907,9 @@ def main():
     # Try getting volume
     volume = get_volume(module, ec2_conn, fail_on_not_found=False)
     if state == "present":
-        if instance:
-            inst = get_instance(module, ec2_conn, instance_id=instance)
-            zone = inst["placement"]["availability_zone"]
-
-            # Use platform attribute to guess whether the instance is Windows or Linux
-            if device_name is None:
-                if inst.get("platform", "") == "Windows":
-                    device_name = "/dev/xvdf"
-                else:
-                    device_name = "/dev/sdf"
-
-            # Check if there is a volume already mounted there.
-            mapped_device = get_mapped_block_device(instance_dict=inst, device_name=device_name)
-            if mapped_device:
-                other_volume_mapped = False
-                if volume:
-                    if volume["volume_id"] != mapped_device["ebs"]["volume_id"]:
-                        other_volume_mapped = True
-                else:
-                    # No volume found so this is another volume
-                    other_volume_mapped = True
-
-                if other_volume_mapped:
-                    module.exit_json(
-                        msg=f"Volume mapping for {device_name} already exists on instance {instance}",
-                        volume_id=mapped_device["ebs"]["volume_id"],
-                        found_volume=volume,
-                        device=device_name,
-                        changed=False,
-                    )
-
-        final_tags = None
-        tags_changed = False
-        if volume:
-            volume, changed = update_volume(module, ec2_conn, volume)
-            if name:
-                if not tags:
-                    tags = boto3_tag_list_to_ansible_dict(volume.get("tags"))
-                tags["Name"] = name
-            final_tags, tags_changed = ensure_tags(
-                module, ec2_conn, volume["volume_id"], "volume", tags, module.params.get("purge_tags")
-            )
-        else:
-            volume, changed = create_volume(module, ec2_conn, zone=zone)
-
-        if detach_vol_flag:
-            volume, attach_changed = detach_volume(module, ec2_conn, volume_dict=volume)
-        elif inst is not None:
-            volume, attach_changed = attach_volume(
-                module, ec2_conn, volume_dict=volume, instance_dict=inst, device_name=device_name
-            )
-        else:
-            attach_changed = False
-
-        # Add device, volume_id and volume_type parameters separately to maintain backward compatibility
-        volume_info = get_volume_info(module, volume, tags=final_tags)
-
-        if tags_changed or attach_changed:
-            changed = True
-
-        module.exit_json(
-            changed=changed,
-            volume=volume_info,
-            device=device_name,
-            volume_id=volume_info["id"],
-            volume_type=volume_info["type"],
-        )
+        ensure_present(ec2_conn, module, volume)
     elif state == "absent":
-        if not name and not param_id:
-            module.fail_json("A volume name or id is required for deletion")
-        if volume and volume.get("state") not in ("deleting", "deleted"):
-            if module.check_mode:
-                module.exit_json(changed=True, msg="Would have deleted volume if not in check mode.")
-            detach_volume(module, ec2_conn, volume_dict=volume)
-            changed = delete_volume(module, ec2_conn, volume_id=volume["volume_id"])
-        module.exit_json(changed=changed)
+        ensure_absent(ec2_conn, module, volume)
 
 
 if __name__ == "__main__":
