@@ -20,7 +20,7 @@ version_added: "1.0.0"
 options:
   policy:
     description:
-      - The name of the SELinux policy to use (e.g. C(targeted)) will be required if I(state) is not C(disabled).
+      - The name of the SELinux policy to use (e.g. C(targeted)) will be required unless O(state=disabled).
     type: str
   state:
     description:
@@ -30,7 +30,7 @@ options:
     type: str
   update_kernel_param:
     description:
-      - If set to I(true), will update also the kernel boot parameters when disabling/enabling SELinux.
+      - If set to V(true), will update also the kernel boot parameters when disabling/enabling SELinux.
       - The C(grubby) tool must be present on the target system for this to work.
     default: false
     type: bool
@@ -107,6 +107,8 @@ from ansible.module_utils.basic import AnsibleModule, missing_required_lib
 from ansible.module_utils.common.process import get_bin_path
 from ansible.module_utils.facts.utils import get_file_lines
 
+from ansible_collections.ansible.posix.plugins.module_utils._respawn import respawn_module, HAS_RESPAWN_UTIL
+
 
 # getter subroutines
 def get_config_state(configfile):
@@ -236,6 +238,8 @@ def main():
     )
 
     if not HAS_SELINUX:
+        if HAS_RESPAWN_UTIL:
+            respawn_module("selinux")
         module.fail_json(msg=missing_required_lib('libselinux-python'), exception=SELINUX_IMP_ERR)
 
     # global vars
