@@ -8,13 +8,12 @@ Test plugin file for netaddr tests: multicast
 """
 
 from __future__ import absolute_import, division, print_function
+
 from ansible_collections.ansible.utils.plugins.plugin_utils.base.ipaddress_utils import (
-    ip_address,
     _need_ipaddress,
+    ip_address,
 )
-from ansible_collections.ansible.utils.plugins.plugin_utils.base.utils import (
-    _validate_args,
-)
+from ansible_collections.ansible.utils.plugins.plugin_utils.base.utils import _validate_args
 
 
 __metaclass__ = type
@@ -30,9 +29,7 @@ DOCUMENTATION = """
         ip:
             description:
             - A string that represents the value against which the test is going to be performed
-            - For example:
-                - "224.0.0.1"
-                - "127.0.0.1"
+            - 'For example: C(224.0.0.1) or C(127.0.0.1)'
             type: str
             required: True
     notes:
@@ -87,7 +84,6 @@ EXAMPLES = r"""
 #     },
 #     "changed": false
 # }
-
 """
 
 RETURN = """
@@ -100,7 +96,7 @@ RETURN = """
 
 @_need_ipaddress
 def _multicast(ip):
-    """ Test for a multicast IP address """
+    """Test for a multicast IP address"""
 
     params = {"ip": ip}
     _validate_args("multicast", DOCUMENTATION, params)
@@ -112,7 +108,7 @@ def _multicast(ip):
 
 
 class TestModule(object):
-    """ network jinja test"""
+    """network jinja test"""
 
     test_map = {"multicast": _multicast}
 
