@@ -70,9 +70,7 @@ def _tmplt_bgp_neighbor(config_data):
     elif config_data["neighbor"].get("default_originate"):
         command += " default-originate"
         if config_data["neighbor"]["default_originate"].get("route_map"):
-            command += " route-map {route_map}".format(
-                **config_data["neighbor"]["default_originate"],
-            )
+            command += " route-map " + config_data["neighbor"]["default_originate"]["route_map"]
         if config_data["neighbor"]["default_originate"].get("always"):
             command += " always"
     elif config_data["neighbor"].get("graceful_restart"):
