@@ -52,6 +52,14 @@ options:
         choices:
             - AzureIaasVM
         type: str
+    policy_type:
+        description:
+            - Defines the type of backup policy
+        default: V1
+        choices:
+            - V1
+            - V2
+        type: str
     schedule_run_time:
         description:
             - The hour to run backups.
@@ -139,6 +147,20 @@ EXAMPLES = '''
       - "Friday"
     time_zone: "Pacific Standard Time"
     schedule_run_time: 8
+
+- name: Create daily enhanced policy
+  azure.azcollection.azure_rm_backuppolicy:
+    vault_name: Vault_Name
+    name: Policy_Name_Enhanced
+    resource_group: Resource_Group_Name
+    policy_type: V2
+    state: present
+    backup_management_type: AzureIaasVM
+    schedule_run_frequency: Daily
+    instant_recovery_snapshot_retention: 7
+    daily_retention_count: 28
+    time_zone: UTC
+    schedule_run_time: 20
 '''
 
 RETURN = '''
@@ -166,6 +188,48 @@ type:
     type: str
     returned: always
     sample: Microsoft.RecoveryServices/vaults/backupPolicies
+properties:
+    description:
+        - Attributes of the backup policy.
+    type: dict
+    returned: always
+    sample: {
+                "backup_management_type": "AzureIaasVM",
+                "instant_rp_details": {},
+                "instant_rp_retention_range_in_days": 5,
+                "protected_items_count": 0,
+                "retention_policy": {
+                    "retention_policy_type": "LongTermRetentionPolicy",
+                    "weekly_schedule": {
+                        "days_of_the_week": [
+                            "Monday",
+                            "Wednesday",
+                            "Thursday"
+                        ],
+                        "retention_duration": {
+                            "count": 4,
+                            "duration_type": "Weeks"
+                        },
+                        "retention_times": [
+                            "2025-04-09T10:00:00.000Z"
+                        ]
+                    }
+                },
+                "schedule_policy": {
+                    "schedule_policy_type": "SimpleSchedulePolicy",
+                    "schedule_run_days": [
+                        "Monday",
+                        "Wednesday",
+                        "Thursday"
+                    ],
+                    "schedule_run_frequency": "Weekly",
+                    "schedule_run_times": [
+                        "2025-04-09T10:00:00.000Z"
+                    ],
+                    "schedule_weekly_frequency": 0
+                },
+                "time_zone": "Pacific Standard Time"
+            }
 '''
 
 from datetime import datetime
@@ -189,6 +253,7 @@ class AzureRMBackupPolicy(AzureRMModuleBase):
             resource_group=dict(type='str', required=True),
             state=dict(type='str', default='present', choices=['present', 'absent']),
             backup_management_type=dict(type='str', choices=['AzureIaasVM']),
+            policy_type=dict(type='str', default='V1', choices=['V1', 'V2']),
             schedule_run_time=dict(type='int'),
             instant_recovery_snapshot_retention=dict(type='int'),
             schedule_run_frequency=dict(type='str', choices=['Daily', 'Weekly']),
@@ -203,6 +268,7 @@ class AzureRMBackupPolicy(AzureRMModuleBase):
         self.name = None
         self.resource_group = None
         self.backup_management_type = None
+        self.policy_type = None
         self.schedule_run_time = None
         self.instant_recovery_snapshot_retention = None
         self.schedule_run_frequency = None
@@ -236,15 +302,12 @@ class AzureRMBackupPolicy(AzureRMModuleBase):
         existing_backup_policy = None
         response = None
 
-        existing_backup_policy = self.get_backup_policy()
-
-        if existing_backup_policy:
-            self.set_results(existing_backup_policy)
+        old_res = self.get_backup_policy()
 
         # either create or update
         if self.state == 'present':
             # check if the backup policy exists
-            if not existing_backup_policy:
+            if not old_res:
                 self.log("Backup policy {0} for vault {1} in resource group {2} does not exist.".format(self.name,
                                                                                                         self.vault_name,
                                                                                                         self.resource_group))
@@ -255,28 +318,57 @@ class AzureRMBackupPolicy(AzureRMModuleBase):
                     return self.results
 
                 response = self.create_or_update_backup_policy()
-                self.set_results(response)
+                self.results.update(self.set_results(response))
 
             # log that we're doing an update
             else:
                 self.log("Backup policy {0} for vault {1} in resource group {2} already exists, updating".format(self.name,
                                                                                                                  self.vault_name,
                                                                                                                  self.resource_group))
-
-                self.results['changed'] = True
+                if self.schedule_run_frequency is not None and\
+                   self.schedule_run_frequency != old_res['properties']['schedule_policy']['schedule_run_frequency']:
+                    self.results['changed'] = True
+                elif self.time_zone is not None and self.time_zone != old_res['properties']['time_zone']:
+                    self.results['changed'] = True
+                elif self.instant_recovery_snapshot_retention is not None and\
+                        self.instant_recovery_snapshot_retention != old_res['properties']['instant_rp_retention_range_in_days']:
+                    self.results['changed'] = True
+                elif self.schedule_weekly_frequency is not None and\
+                        self.schedule_weekly_frequency != old_res['properties']['schedule_policy']['schedule_weekly_frequency']:
+                    self.results['changed'] = True
+                if self.weekly_retention_count is not None:
+                    if self.weekly_retention_count !=\
+                       old_res['properties']['retention_policy'].get('weekly_schedule', {}).get('retention_duration', {}).get('count'):
+                        self.results['changed'] = True
+                if self.daily_retention_count is not None:
+                    if self.daily_retention_count !=\
+                       old_res['properties']['retention_policy'].get('daily_schedule', {}).get('retention_duration', {}).get('count'):
+                        self.results['changed'] = True
+                if self.schedule_days is not None:
+                    if old_res['properties']['schedule_policy'].get('schedule_run_days') is not None:
+                        if set(self.schedule_days) != set(old_res['properties']['schedule_policy']['schedule_run_days']):
+                            self.results['changed'] = True
+                    else:
+                        self.results['changed'] = True
 
                 if self.check_mode:
+                    self.results.update(old_res)
+                    self.results['changed'] = True
                     return self.results
-
-                response = self.create_or_update_backup_policy()
-                self.set_results(response)
+                else:
+                    if self.results['changed']:
+                        response = self.create_or_update_backup_policy()
+                        self.results.update(self.set_results(response))
+                    else:
+                        self.results.update(old_res)
 
         elif self.state == 'absent':
-            if existing_backup_policy:
+            if old_res:
                 self.log("Delete backup policy")
                 self.results['changed'] = True
 
                 if self.check_mode:
+                    self.results.update(old_res)
                     return self.results
 
                 self.delete_backup_policy()
@@ -340,10 +432,15 @@ class AzureRMBackupPolicy(AzureRMModuleBase):
                 self.fail(e)
 
             # create a schedule policy based on schedule_run_frequency
-            schedule_policy = self.recovery_services_backup_models.SimpleSchedulePolicy(schedule_run_frequency=self.schedule_run_frequency,
-                                                                                        schedule_run_days=self.schedule_days,
-                                                                                        schedule_run_times=schedule_run_times_as_datetimes,
-                                                                                        schedule_weekly_frequency=self.schedule_weekly_frequency)
+            if self.policy_type == 'V1':
+                schedule_policy = self.recovery_services_backup_models.SimpleSchedulePolicy(schedule_run_frequency=self.schedule_run_frequency,
+                                                                                            schedule_run_days=self.schedule_days,
+                                                                                            schedule_run_times=schedule_run_times_as_datetimes,
+                                                                                            schedule_weekly_frequency=self.schedule_weekly_frequency)
+            elif self.policy_type == 'V2':
+                schedule_policy = self.recovery_services_backup_models.SimpleSchedulePolicyV2(
+                    schedule_run_frequency=self.schedule_run_frequency, daily_schedule=self.recovery_services_backup_models.WeeklySchedule(
+                        schedule_run_days=self.schedule_days, schedule_run_times=schedule_run_times_as_datetimes))
 
             daily_retention_schedule = None
             weekly_retention_schedule = None
@@ -373,7 +470,8 @@ class AzureRMBackupPolicy(AzureRMModuleBase):
                                                                 schedule_policy=schedule_policy,
                                                                 retention_policy=retention_policy,
                                                                 instant_rp_retention_range_in_days=self.instant_recovery_snapshot_retention,
-                                                                time_zone=self.time_zone)
+                                                                time_zone=self.time_zone,
+                                                                policy_type=self.policy_type)
 
             if policy_definition:
                 policy_resource = self.recovery_services_backup_models.ProtectionPolicyResource(properties=policy_definition)
@@ -432,20 +530,19 @@ class AzureRMBackupPolicy(AzureRMModuleBase):
         except ResourceNotFoundError as ex:
             self.log("Could not find backup policy {0} for vault {1} in resource group {2}".format(self.name, self.vault_name, self.resource_group))
 
-        return policy
+        return self.set_results(policy)
 
     def set_results(self, policy):
+        result = dict()
         if policy:
-            self.results['id'] = policy.id
-            self.results['location'] = policy.location
-            self.results['name'] = policy.name
-            self.results['type'] = policy.type
-
+            result['id'] = policy.id
+            result['location'] = policy.location
+            result['name'] = policy.name
+            result['type'] = policy.type
+            result['properties'] = policy.properties.as_dict()
+            return result
         else:
-            self.results['id'] = None
-            self.results['location'] = None
-            self.results['name'] = None
-            self.results['type'] = None
+            return None
 
 
 def main():
