@@ -43,6 +43,8 @@ options:
         choices:
             - windows
             - linux
+            - Windows
+            - Linux
     vm_size:
         description:
             - A valid Azure VM size value. For example, C(Standard_D4).
@@ -140,6 +142,11 @@ options:
         choices:
             - standard
             - premium
+    is_authentication_with_ssh_key:
+        description:
+            - Indicates whether this virtual machine uses an SSH key for authentication.
+            - I(is_authentication_with_ssh_key=True) when I(ssh_key) is set for ssh authentication.
+        type: bool
     state:
         description:
             - Assert the state of the Virtual Machine.
@@ -169,7 +176,7 @@ EXAMPLES = '''
     os_type: linux
     vm_size: Standard_A2_v2
     user_name: vmadmin
-    password: ZSuppas$$21!
+    password: "{{ password }}"
     lab_subnet:
       name: myvnSubnet
       virtual_network_name: myvn
@@ -246,7 +253,7 @@ class AzureRMVirtualMachine(AzureRMModuleBase):
             ),
             os_type=dict(
                 type='str',
-                choices=['linux', 'windows']
+                choices=['linux', 'windows', 'Linux', 'Windows']
             ),
             vm_size=dict(
                 type='str'
@@ -322,6 +329,9 @@ class AzureRMVirtualMachine(AzureRMModuleBase):
                 type='str',
                 choices=['standard', 'premium']
             ),
+            is_authentication_with_ssh_key=dict(
+                type='bool'
+            ),
             state=dict(
                 type='str',
                 default='present',
@@ -330,8 +340,8 @@ class AzureRMVirtualMachine(AzureRMModuleBase):
         )
 
         required_if = [
-            ('state', 'present', [
-             'image', 'lab_subnet', 'vm_size', 'os_type'])
+            ('state', 'present', ['image', 'lab_subnet', 'vm_size', 'os_type']),
+            ('is_authentication_with_ssh_key', True, ['ssh_key'])
         ]
 
         self.resource_group = None
@@ -367,13 +377,13 @@ class AzureRMVirtualMachine(AzureRMModuleBase):
                 template = "/subscriptions/{0}/resourceGroups/{1}/providers/Microsoft.DevTestLab/labs/{2}/artifactsources/{3}{4}"
                 artifact['artifact_id'] = template.format(self.subscription_id, self.resource_group, self.lab_name, source_name, source_path)
 
-        self.lab_virtual_machine['size'] = self.lab_virtual_machine.pop('vm_size')
-        self.lab_virtual_machine['os_type'] = _snake_to_camel(self.lab_virtual_machine['os_type'], True)
+        self.lab_virtual_machine['size'] = self.lab_virtual_machine.pop('vm_size') if self.lab_virtual_machine.get('vm_size') else None
+        self.lab_virtual_machine['os_type'] = _snake_to_camel(self.lab_virtual_machine['os_type']) if self.lab_virtual_machine.get('os_type') else None
 
         if self.lab_virtual_machine.get('storage_type'):
             self.lab_virtual_machine['storage_type'] = _snake_to_camel(self.lab_virtual_machine['storage_type'], True)
 
-        lab_subnet = self.lab_virtual_machine.pop('lab_subnet')
+        lab_subnet = self.lab_virtual_machine.pop('lab_subnet') if self.lab_virtual_machine.get('lab_subnet') else dict()
 
         if isinstance(lab_subnet, str):
             vn_and_subnet = lab_subnet.split('/subnets/')
@@ -431,6 +441,12 @@ class AzureRMVirtualMachine(AzureRMModuleBase):
                 if len(self.lab_virtual_machine.get('artifacts', [])) != old_response['artifact_deployment_status']['total_artifacts']:
                     self.module.warn("Property 'artifacts' cannot be changed")
 
+                if self.lab_virtual_machine.get('is_authentication_with_ssh_key') is not None:
+                    if bool(old_response['is_authentication_with_ssh_key']) != bool(self.lab_virtual_machine['is_authentication_with_ssh_key']):
+                        self.module.warn("Property 'is_authentication_with_ssh_key' cannot be changed")
+                else:
+                    self.lab_virtual_machine['is_authentication_with_ssh_key'] = old_response['is_authentication_with_ssh_key']
+
                 if self.lab_virtual_machine.get('disallow_public_ip_address') is not None:
                     if old_response['disallow_public_ip_address'] != self.lab_virtual_machine.get('disallow_public_ip_address'):
                         self.module.warn("Property 'disallow_public_ip_address' cannot be changed")
