@@ -56,18 +56,20 @@ options:
     os_type:
         description:
             - This property allows you to specify the type of the OS that is included in the disk when creating a VM from a managed image.
+            - Required when creating.
         choices:
             - windows
             - linux
-        required: true
+            - Windows
+            - Linux
         type: str
     os_state:
         description:
             - The allowed values for OS State are C(generalized).
+            - Required when creating.
         choices:
             - generalized
             - specialized
-        required: true
         type: str
     hypervgeneration:
         description:
@@ -76,6 +78,14 @@ options:
             - V1
             - V2
         type: str
+    architecture:
+        description:
+            - This property allows you to specify the hardware architecture of the Virtual Machines.
+            - Arm64 is only supported with Hyper V Version 2.
+        choices:
+            - Arm64
+            - x64
+        type: str
     end_of_life_date:
         description:
             - The end of life date of the gallery Image Definition.
@@ -86,7 +96,7 @@ options:
     identifier:
         description:
             - Image identifier.
-        required: true
+            - Required when creating.
         type: dict
         suboptions:
             publisher:
@@ -144,6 +154,7 @@ options:
                 description:
                     - A list of disallowed disk types.
                 type: list
+                elements: str
     purchase_plan:
         description:
             - Purchase plan.
@@ -161,6 +172,22 @@ options:
                 description:
                     - The product ID.
                 type: str
+    features:
+        description:
+            - A list of gallery image features.
+        type: list
+        elements: dict
+        suboptions:
+            name:
+                description:
+                    - The name of the gallery image feature.
+                type: str
+                required: True
+            value:
+                description:
+                    - The value of the gallery image feature.
+                type: str
+                required: True
     state:
         description:
             - Assert the state of the GalleryImage.
@@ -205,15 +232,8 @@ id:
 
 import time
 import json
-import re
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBaseExt
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_rest import GenericRestClient
-from copy import deepcopy
-try:
-    from msrestazure.azure_exceptions import CloudError
-except ImportError:
-    # This is handled in azure_rm_common
-    pass
 
 
 class Actions:
@@ -225,73 +245,60 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
         self.module_arg_spec = dict(
             resource_group=dict(
                 type='str',
-                updatable=False,
-                disposition='resourceGroupName',
                 required=True
             ),
             gallery_name=dict(
                 type='str',
-                updatable=False,
-                disposition='galleryName',
                 required=True
             ),
             name=dict(
                 type='str',
-                updatable=False,
-                disposition='galleryImageName',
                 required=True
             ),
             location=dict(
                 type='str',
-                updatable=False,
-                disposition='/'
             ),
             description=dict(
                 type='str',
-                disposition='/properties/*'
             ),
             eula=dict(
                 type='str',
-                disposition='/properties/*'
             ),
             privacy_statement_uri=dict(
                 type='str',
-                disposition='/properties/privacyStatementUri'
             ),
             release_note_uri=dict(
                 type='str',
-                disposition='/properties/releaseNoteUri'
             ),
             os_type=dict(
                 type='str',
-                disposition='/properties/osType',
-                choices=['windows',
-                         'linux']
+                choices=['windows', 'Windows',
+                         'Linux', 'linux']
             ),
             os_state=dict(
                 type='str',
-                disposition='/properties/osState',
                 choices=['generalized',
                          'specialized']
             ),
             hypervgeneration=dict(
                 type='str',
-                disposition='/properties/hyperVGeneration',
                 choices=['V1',
                          'V2']
             ),
+            architecture=dict(
+                type='str',
+                choices=['Arm64',
+                         'x64']
+            ),
             end_of_life_date=dict(
                 type='str',
-                disposition='/properties/endOfLifeDate'
             ),
             identifier=dict(
                 type='dict',
-                disposition='/properties/*',
                 options=dict(
                     publisher=dict(
                         type='str',
                         required=True,
-                        updatable=False
                     ),
                     offer=dict(
                         type='str',
@@ -305,11 +312,9 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
             ),
             recommended=dict(
                 type='dict',
-                disposition='/properties/*',
                 options=dict(
                     v_cpus=dict(
                         type='dict',
-                        disposition='vCPUs',
                         options=dict(
                             min=dict(
                                 type='int'
@@ -334,17 +339,15 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
             ),
             disallowed=dict(
                 type='dict',
-                disposition='/properties/*',
                 options=dict(
                     disk_types=dict(
                         type='list',
-                        disposition='diskTypes'
+                        elements='str',
                     )
                 )
             ),
             purchase_plan=dict(
                 type='dict',
-                disposition='/properties/purchasePlan',
                 options=dict(
                     name=dict(
                         type='str'
@@ -357,6 +360,20 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
                     )
                 )
             ),
+            features=dict(
+                type='list',
+                elements='dict',
+                options=dict(
+                    name=dict(
+                        type='str',
+                        required=True
+                    ),
+                    value=dict(
+                        type='str',
+                        required=True
+                    )
+                )
+            ),
             state=dict(
                 type='str',
                 default='present',
@@ -377,8 +394,9 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
         self.to_do = Actions.NoAction
 
         self.body = {}
+        self.body['properties'] = {}
         self.query_parameters = {}
-        self.query_parameters['api-version'] = '2019-07-01'
+        self.query_parameters['api-version'] = '2022-03-03'
         self.header_parameters = {}
         self.header_parameters['Content-Type'] = 'application/json; charset=utf-8'
 
@@ -387,13 +405,46 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
                                                    supports_tags=True)
 
     def exec_module(self, **kwargs):
-        for key in list(self.module_arg_spec.keys()):
+        for key in list(self.module_arg_spec.keys()) + ['tags']:
             if hasattr(self, key):
                 setattr(self, key, kwargs[key])
             elif kwargs[key] is not None:
-                self.body[key] = kwargs[key]
-
-        self.inflate_parameters(self.module_arg_spec, self.body, 0)
+                if key == 'description':
+                    self.body['properties']['description'] = kwargs[key]
+                elif key == 'eula':
+                    self.body['properties']['eula'] = kwargs[key]
+                elif key == 'privacy_statement_uri':
+                    self.body['properties']['privacyStatementUri'] = kwargs[key]
+                elif key == 'release_note_uri':
+                    self.body['properties']['releaseNoteUri'] = kwargs[key]
+                elif key == 'os_type':
+                    self.body['properties']['osType'] = kwargs[key]
+                elif key == 'os_state':
+                    self.body['properties']['osState'] = kwargs[key]
+                elif key == 'hypervgeneration':
+                    self.body['properties']['hyperVGeneration'] = kwargs[key]
+                elif key == 'architecture':
+                    self.body['properties']['architecture'] = kwargs[key]
+                elif key == 'end_of_life_date':
+                    self.body['properties']['endOfLifeDate'] = kwargs[key]
+                elif key == 'identifier':
+                    self.body['properties']['identifier'] = kwargs[key]
+                elif key == 'recommended':
+                    self.body['properties']['recommended'] = {}
+                    for item in kwargs[key].keys():
+                        if item == 'v_cpus':
+                            self.body['properties']['recommended']['vCPUs'] = kwargs[key].get('v_cpus')
+                        elif item == 'memory':
+                            self.body['properties']['recommended']['memory'] = kwargs[key].get('memory')
+                elif key == 'disallowed':
+                    self.body['properties']['disallowed'] = {}
+                    self.body['properties']['disallowed']['diskTypes'] = kwargs[key].get('disk_types')
+                elif key == 'purchase_plan':
+                    self.body['properties']['purchasePlan'] = kwargs[key]
+                elif key == 'features':
+                    self.body['properties']['features'] = kwargs[key]
+                else:
+                    self.body[key] = kwargs[key]
 
         old_response = None
         response = None
@@ -436,11 +487,60 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
             if self.state == 'absent':
                 self.to_do = Actions.Delete
             else:
-                modifiers = {}
-                self.create_compare_modifiers(self.module_arg_spec, '', modifiers)
-                self.results['modifiers'] = modifiers
-                self.results['compare'] = []
-                if not self.default_compare(modifiers, self.body, old_response, '', self.results):
+                if self.body['properties'].get('description') is not None and \
+                   self.body['properties']['description'] != old_response['properties'].get('description'):
+                    self.to_do = Actions.Update
+                elif self.body['properties'].get('eula') is not None and self.body['properties']['eula'] != old_response['properties'].get('eula'):
+                    self.to_do = Actions.Update
+                elif (self.body['properties'].get('privacyStatementUri') is not None and
+                      self.body['properties']['privacyStatementUri'] != old_response['properties'].get('privacyStatementUri')):
+                    self.to_do = Actions.Update
+                elif (self.body['properties'].get('releaseNoteUri') is not None and
+                      self.body['properties']['releaseNoteUri'] != old_response['properties'].get('releaseNoteUri')):
+                    self.to_do = Actions.Update
+                elif (self.body['properties'].get('osType') is not None and
+                      self.body['properties']['osType'].lower() != old_response['properties'].get('osType', '').lower()):
+                    self.to_do = Actions.Update
+                elif (self.body['properties'].get('osState') is not None and
+                      self.body['properties']['osState'].lower() != old_response['properties'].get('osState', '').lower()):
+                    self.to_do = Actions.Update
+                elif (self.body['properties'].get('hyperVGeneration') is not None and
+                      self.body['properties']['hyperVGeneration'] != old_response['properties'].get('hyperVGeneration')):
+                    self.to_do = Actions.Update
+                elif (self.body['properties'].get('architecture') is not None and
+                      self.body['properties']['architecture'] != old_response['properties'].get('architecture')):
+                    self.to_do = Actions.Update
+                elif (self.body['properties'].get('endOfLifeDate') is not None and
+                      self.body['properties']['endOfLifeDate'] != old_response['properties'].get('endOfLifeDate')):
+                    self.to_do = Actions.Update
+                elif (self.body['properties'].get('identifier') is not None and
+                      self.body['properties']['identifier'].get('offer') != old_response['properties']['identifier'].get('offer') or
+                      self.body['properties']['identifier'].get('sku') != old_response['properties']['identifier'].get('sku')):
+                    self.to_do = Actions.Update
+                elif self.body['properties'].get('recommended') is not None:
+                    if self.body['properties']['recommended'].get('vCPUS') is not None:
+                        for item in self.body['properties']['recommended']['vCPUS'].keys():
+                            if self.body['properties']['recommended']['vCPUS'].get(item) != old_response['properties']['recommended']['vCPUS'].get(item):
+                                self.to_do = Actions.Update
+                    elif (self.body['properties']['recommended'].get('memory') is not None and
+                          not all(self.body['properties']['recommended']['memory'].get(item) == old_response['properties']['recommended']['memory'].get(item)
+                          for item in self.body['properties']['recommended']['memory'].keys())):
+                        self.to_do = Actions.Update
+                elif (self.body['properties'].get('disallowed') is not None and
+                      self.body['properties']['disallowed'].get('diskTypes') != old_response['properties']['disallowed'].get('diskTypes')):
+                    self.to_do = Actions.Update
+                elif self.body['properties'].get('purchasePlan') is not None:
+                    for item in self.body['properties']['purchasePlan'].keys():
+                        if self.body['properties']['purchasePlan'][item] != old_response['properties']['purchasePlan'].get(item):
+                            self.to_do = Actions.Update
+                elif self.body['properties'].get('features') is not None:
+                    if old_response['properties'].get('features') is None:
+                        self.to_do = Actions.Update
+                    else:
+                        if not all(item in old_response['properties']['features'] for item in self.body['properties']['features']):
+                            self.to_do = Actions.Update
+                update_tags, self.body['tags'] = self.update_tags(old_response.get('tags'))
+                if update_tags:
                     self.to_do = Actions.Update
 
         if (self.to_do == Actions.Create) or (self.to_do == Actions.Update):
@@ -492,14 +592,16 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
                                               self.status_code,
                                               600,
                                               30)
-        except CloudError as exc:
+        except Exception as exc:
             self.log('Error attempting to create the GalleryImage instance.')
             self.fail('Error creating the GalleryImage instance: {0}'.format(str(exc)))
 
-        try:
-            response = json.loads(response.text)
-        except Exception:
-            response = {'text': response.text}
+        if hasattr(response, 'body'):
+            response = json.loads(response.body())
+        elif hasattr(response, 'context'):
+            response = response.context['deserialized_data']
+        else:
+            self.fail("Create or Updating fail, no match message return, return info as {0}".format(response))
 
         return response
 
@@ -514,7 +616,7 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
                                               self.status_code,
                                               600,
                                               30)
-        except CloudError as e:
+        except Exception as e:
             self.log('Error attempting to delete the GalleryImage instance.')
             self.fail('Error deleting the GalleryImage instance: {0}'.format(str(e)))
 
@@ -532,11 +634,11 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
                                               self.status_code,
                                               600,
                                               30)
-            response = json.loads(response.text)
+            response = json.loads(response.body())
             found = True
             self.log("Response : {0}".format(response))
             # self.log("AzureFirewall instance : {0} found".format(response.name))
-        except CloudError as e:
+        except Exception as e:
             self.log('Did not find the AzureFirewall instance.')
         if found is True:
             return response
