@@ -43,16 +43,16 @@ author:
 '''
 
 EXAMPLES = '''
-  - name: Get instance of MariaDB Server
-    azure_rm_mariadbserver_info:
-      resource_group: myResourceGroup
-      name: server_name
+- name: Get instance of MariaDB Server
+  azure_rm_mariadbserver_info:
+    resource_group: myResourceGroup
+    name: server_name
 
-  - name: List instances of MariaDB Server
-    azure_rm_mariadbserver_info:
-      resource_group: myResourceGroup
-      tags:
-        - key:value
+- name: List instances of MariaDB Server
+  azure_rm_mariadbserver_info:
+    resource_group: myResourceGroup
+    tags:
+      - key:value
 '''
 
 RETURN = '''
@@ -155,9 +155,7 @@ servers:
 
 try:
     from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
-    from msrestazure.azure_exceptions import CloudError
-    from azure.mgmt.rdbms.mariadb import MariaDBManagementClient
-    from msrest.serialization import Model
+    from azure.core.exceptions import ResourceNotFoundError
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -189,9 +187,6 @@ class AzureRMMariaDbServerInfo(AzureRMModuleBase):
         super(AzureRMMariaDbServerInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=False, facts_module=True)
 
     def exec_module(self, **kwargs):
-        is_old_facts = self.module._name == 'azure_rm_mariadbserver_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_mariadbserver_facts' module has been renamed to 'azure_rm_mariadbserver_info'", version=(2.9, ))
 
         for key in self.module_arg_spec:
             setattr(self, key, kwargs[key])
@@ -210,7 +205,7 @@ class AzureRMMariaDbServerInfo(AzureRMModuleBase):
             response = self.mariadb_client.servers.get(resource_group_name=self.resource_group,
                                                        server_name=self.name)
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             self.log('Could not get facts for MariaDB Server.')
 
         if response and self.has_tags(response.tags, self.tags):
@@ -224,7 +219,7 @@ class AzureRMMariaDbServerInfo(AzureRMModuleBase):
         try:
             response = self.mariadb_client.servers.list_by_resource_group(resource_group_name=self.resource_group)
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except Exception as e:
             self.log('Could not get facts for MariaDB Servers.')
 
         if response is not None:
