@@ -41,16 +41,16 @@ author:
 '''
 
 EXAMPLES = '''
-  - name: Get instance of MySQL Firewall Rule
-    azure_rm_mysqlfirewallrule_info:
-      resource_group: myResourceGroup
-      server_name: server_name
-      name: firewall_rule_name
+- name: Get instance of MySQL Firewall Rule
+  azure_rm_mysqlfirewallrule_info:
+    resource_group: myResourceGroup
+    server_name: server_name
+    name: firewall_rule_name
 
-  - name: List instances of MySQL Firewall Rule
-    azure_rm_mysqlfirewallrule_info:
-      resource_group: myResourceGroup
-      server_name: server_name
+- name: List instances of MySQL Firewall Rule
+  azure_rm_mysqlfirewallrule_info:
+    resource_group: myResourceGroup
+    server_name: server_name
 '''
 
 RETURN = '''
@@ -95,9 +95,7 @@ rules:
 
 try:
     from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
-    from msrestazure.azure_operation import AzureOperationPoller
     from azure.core.exceptions import ResourceNotFoundError
-    from msrest.serialization import Model
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -129,9 +127,6 @@ class AzureRMMySqlFirewallRuleInfo(AzureRMModuleBase):
         super(AzureRMMySqlFirewallRuleInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=False)
 
     def exec_module(self, **kwargs):
-        is_old_facts = self.module._name == 'azure_rm_mysqlfirewallrule_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_mysqlfirewallrule_facts' module has been renamed to 'azure_rm_mysqlfirewallrule_info'", version=(2.9, ))
 
         for key in self.module_arg_spec:
             setattr(self, key, kwargs[key])
