@@ -20,14 +20,17 @@ options:
         description:
             - Name of resource group.
         required: true
+        type: str
     name:
         description:
             - Name of the route table.
         required: true
+        type: str
     state:
         description:
             - Assert the state of the route table. Use C(present) to create or update and C(absent) to delete.
         default: present
+        type: str
         choices:
             - absent
             - present
@@ -40,6 +43,7 @@ options:
         description:
             - Region of the resource.
             - Derived from I(resource_group) if not specified.
+        type: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -51,19 +55,19 @@ author:
 '''
 
 EXAMPLES = '''
-    - name: Create a route table
-      azure_rm_routetable:
-        resource_group: myResourceGroup
-        name: myRouteTable
-        disable_bgp_route_propagation: False
-        tags:
-          purpose: testing
+- name: Create a route table
+  azure_rm_routetable:
+    resource_group: myResourceGroup
+    name: myRouteTable
+    disable_bgp_route_propagation: false
+    tags:
+      purpose: testing
 
-    - name: Delete a route table
-      azure_rm_routetable:
-        resource_group: myResourceGroup
-        name: myRouteTable
-        state: absent
+- name: Delete a route table
+  azure_rm_routetable:
+    resource_group: myResourceGroup
+    name: myRouteTable
+    state: absent
 '''
 RETURN = '''
 changed:
@@ -134,9 +138,13 @@ class AzureRMRouteTable(AzureRMModuleBase):
             if not self.check_mode:
                 self.delete_table()
         elif self.state == 'present':
+            routes = []
+            subnets = None
             if not result:
                 changed = True  # create new route table
             else:  # check update
+                routes = result.routes
+                subnets = result.subnets
                 update_tags, self.tags = self.update_tags(result.tags)
                 if update_tags:
                     changed = True
@@ -146,6 +154,8 @@ class AzureRMRouteTable(AzureRMModuleBase):
             if changed:
                 result = self.network_models.RouteTable(location=self.location,
                                                         tags=self.tags,
+                                                        routes=routes,
+                                                        subnets=subnets,
                                                         disable_bgp_route_propagation=self.disable_bgp_route_propagation)
                 if not self.check_mode:
                     result = self.create_or_update_table(result)
