@@ -24,13 +24,17 @@ options:
     name:
         description:
             - Only show results for a specific security group.
+        type: str
     resource_group:
         description:
             - Name of the resource group to use.
         required: true
+        type: str
     tags:
         description:
             - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
+        type: list
+        elements: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -42,15 +46,14 @@ author:
 '''
 
 EXAMPLES = '''
-    - name: Get facts for one security group
-      azure_rm_securitygroup_info:
-        resource_group: myResourceGroup
-        name: secgroup001
-
-    - name: Get facts for all security groups
-      azure_rm_securitygroup_info:
-        resource_group: myResourceGroup
+- name: Get facts for one security group
+  azure_rm_securitygroup_info:
+    resource_group: myResourceGroup
+    name: secgroup001
 
+- name: Get facts for all security groups
+  azure_rm_securitygroup_info:
+    resource_group: myResourceGroup
 '''
 
 RETURN = '''
@@ -246,7 +249,7 @@ securitygroups:
 '''  # NOQA
 
 try:
-    from msrestazure.azure_exceptions import CloudError
+    from azure.core.exceptions import ResourceNotFoundError
 except Exception:
     # This is handled in azure_rm_common
     pass
@@ -318,7 +321,7 @@ class AzureRMSecurityGroupInfo(AzureRMModuleBase):
         self.module_arg_spec = dict(
             name=dict(type='str'),
             resource_group=dict(required=True, type='str'),
-            tags=dict(type='list'),
+            tags=dict(type='list', elements='str'),
         )
 
         self.results = dict(
@@ -336,10 +339,6 @@ class AzureRMSecurityGroupInfo(AzureRMModuleBase):
 
     def exec_module(self, **kwargs):
 
-        is_old_facts = self.module._name == 'azure_rm_securitygroup_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_securitygroup_facts' module has been renamed to 'azure_rm_securitygroup_info'", version=(2.9, ))
-
         for key in self.module_arg_spec:
             setattr(self, key, kwargs[key])
 
@@ -348,10 +347,6 @@ class AzureRMSecurityGroupInfo(AzureRMModuleBase):
         else:
             info = self.list_items()
 
-        if is_old_facts:
-            self.results['ansible_facts'] = {
-                'azure_securitygroups': info
-            }
         self.results['securitygroups'] = info
 
         return self.results
@@ -363,7 +358,7 @@ class AzureRMSecurityGroupInfo(AzureRMModuleBase):
 
         try:
             item = self.network_client.network_security_groups.get(self.resource_group, self.name)
-        except CloudError:
+        except ResourceNotFoundError:
             pass
 
         if item and self.has_tags(item.tags, self.tags):
