@@ -180,10 +180,6 @@ class AzureRMVirtualMachineExtensionInfo(AzureRMModuleBase):
         super(AzureRMVirtualMachineExtensionInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=False, facts_module=True)
 
     def exec_module(self, **kwargs):
-        is_old_facts = self.module._name == 'azure_rm_virtualmachineextension_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_virtualmachineextension_facts' module has been renamed to 'azure_rm_virtualmachineextension_info'",
-                                  version=(2.9, ))
 
         for key in self.module_arg_spec:
             setattr(self, key, kwargs[key])
