@@ -2,13 +2,14 @@
 
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import (absolute_import, division, print_function)
+from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 
 class ModuleDocFragment(object):
     # Standard files documentation fragment
-    DOCUMENTATION = r'''
+    DOCUMENTATION = r"""
 options:
   owner_key:
     description:
@@ -23,4 +24,4 @@ options:
     - For example, to indicate who created this object.
     - If the value is not specified in the task, the value of environment variable C(ACI_OWNER_TAG) will be used instead.
     type: str
-'''
+"""
