@@ -2,11 +2,14 @@
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2021, Cisco Systems
-# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSE or
+# https://www.gnu.org/licenses/gpl-3.0.txt)
+
+from __future__ import absolute_import, division, print_function
 
-from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 from ansible.plugins.action import ActionBase
+
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
         AnsibleArgSpecValidator,
@@ -24,10 +27,14 @@ from ansible_collections.cisco.dnac.plugins.plugin_utils.dnac import (
 # Get common arguments specification
 argument_spec = dnac_argument_spec()
 # Add arguments specific for this module
-argument_spec.update(dict(
-    deviceId=dict(type="str"),
-    headers=dict(type="dict"),
-))
+argument_spec.update(
+    dict(
+        limit=dict(type="float"),
+        offset=dict(type="float"),
+        deviceId=dict(type="str"),
+        headers=dict(type="dict"),
+    )
+)
 
 required_if = []
 required_one_of = []
@@ -38,7 +45,9 @@ required_together = []
 class ActionModule(ActionBase):
     def __init__(self, *args, **kwargs):
         if not ANSIBLE_UTILS_IS_INSTALLED:
-            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
+            raise AnsibleActionFail(
+                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
+            )
         super(ActionModule, self).__init__(*args, **kwargs)
         self._supports_async = False
         self._supports_check_mode = True
@@ -64,6 +73,8 @@ class ActionModule(ActionBase):
 
     def get_object(self, params):
         new_object = dict(
+            limit=params.get("limit"),
+            offset=params.get("offset"),
             device_id=params.get("deviceId"),
             headers=params.get("headers"),
         )
@@ -83,7 +94,7 @@ class ActionModule(ActionBase):
         if id:
             response = dnac.exec(
                 family="eox",
-                function='get_eox_details_per_device',
+                function="get_eox_details_per_device",
                 params=self.get_object(self._task.args),
             )
             self._result.update(dict(dnac_response=response))
@@ -92,7 +103,7 @@ class ActionModule(ActionBase):
         if not id:
             response = dnac.exec(
                 family="eox",
-                function='get_eox_status_for_all_devices',
+                function="get_eox_status_for_all_devices",
                 params=self.get_object(self._task.args),
             )
             self._result.update(dict(dnac_response=response))
