@@ -2,11 +2,14 @@
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2021, Cisco Systems
-# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSE or
+# https://www.gnu.org/licenses/gpl-3.0.txt)
+
+from __future__ import absolute_import, division, print_function
 
-from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 from ansible.plugins.action import ActionBase
+
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
         AnsibleArgSpecValidator,
@@ -24,25 +27,27 @@ from ansible_collections.cisco.dnac.plugins.plugin_utils.dnac import (
 # Get common arguments specification
 argument_spec = dnac_argument_spec()
 # Add arguments specific for this module
-argument_spec.update(dict(
-    eventIds=dict(type="str"),
-    startTime=dict(type="float"),
-    endTime=dict(type="float"),
-    category=dict(type="str"),
-    type=dict(type="str"),
-    severity=dict(type="str"),
-    domain=dict(type="str"),
-    subDomain=dict(type="str"),
-    source=dict(type="str"),
-    offset=dict(type="float"),
-    limit=dict(type="float"),
-    sortBy=dict(type="str"),
-    order=dict(type="str"),
-    tags=dict(type="str"),
-    namespace=dict(type="str"),
-    siteId=dict(type="str"),
-    headers=dict(type="dict"),
-))
+argument_spec.update(
+    dict(
+        eventIds=dict(type="str"),
+        startTime=dict(type="float"),
+        endTime=dict(type="float"),
+        category=dict(type="str"),
+        type=dict(type="str"),
+        severity=dict(type="str"),
+        domain=dict(type="str"),
+        subDomain=dict(type="str"),
+        source=dict(type="str"),
+        offset=dict(type="float"),
+        limit=dict(type="float"),
+        sortBy=dict(type="str"),
+        order=dict(type="str"),
+        tags=dict(type="str"),
+        namespace=dict(type="str"),
+        siteId=dict(type="str"),
+        headers=dict(type="dict"),
+    )
+)
 
 required_if = []
 required_one_of = []
@@ -53,7 +58,9 @@ required_together = []
 class ActionModule(ActionBase):
     def __init__(self, *args, **kwargs):
         if not ANSIBLE_UTILS_IS_INSTALLED:
-            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
+            raise AnsibleActionFail(
+                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
+            )
         super(ActionModule, self).__init__(*args, **kwargs)
         self._supports_async = False
         self._supports_check_mode = True
@@ -111,7 +118,7 @@ class ActionModule(ActionBase):
 
         response = dnac.exec(
             family="event_management",
-            function='get_notifications',
+            function="get_notifications",
             params=self.get_object(self._task.args),
         )
         self._result.update(dict(dnac_response=response))
