@@ -2,11 +2,14 @@
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2021, Cisco Systems
-# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSE or
+# https://www.gnu.org/licenses/gpl-3.0.txt)
+
+from __future__ import absolute_import, division, print_function
 
-from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 from ansible.plugins.action import ActionBase
+
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
         AnsibleArgSpecValidator,
@@ -29,28 +32,29 @@ from ansible_collections.cisco.dnac.plugins.plugin_utils.exceptions import (
 # Get common arguments specification
 argument_spec = dnac_argument_spec()
 # Add arguments specific for this module
-argument_spec.update(dict(
-    state=dict(type="str", default="present", choices=["present", "absent"]),
-    siteNameHierarchy=dict(type="str"),
-    virtualNetworkName=dict(type="str"),
-    isLayer2Only=dict(type="bool"),
-    ipPoolName=dict(type="str"),
-    vlanId=dict(type="str"),
-    vlanName=dict(type="str"),
-    autoGenerateVlanName=dict(type="bool"),
-    trafficType=dict(type="str"),
-    scalableGroupName=dict(type="str"),
-    isL2FloodingEnabled=dict(type="bool"),
-    isThisCriticalPool=dict(type="bool"),
-    isWirelessPool=dict(type="bool"),
-    isIpDirectedBroadcast=dict(type="bool"),
-    isCommonPool=dict(type="bool"),
-    isBridgeModeVm=dict(type="bool"),
-    poolType=dict(type="str"),
-))
+argument_spec.update(
+    dict(
+        state=dict(type="str", default="present", choices=["present", "absent"]),
+        siteNameHierarchy=dict(type="str"),
+        virtualNetworkName=dict(type="str"),
+        isLayer2Only=dict(type="bool"),
+        ipPoolName=dict(type="str"),
+        vlanId=dict(type="str"),
+        vlanName=dict(type="str"),
+        autoGenerateVlanName=dict(type="bool"),
+        trafficType=dict(type="str"),
+        scalableGroupName=dict(type="str"),
+        isL2FloodingEnabled=dict(type="bool"),
+        isThisCriticalPool=dict(type="bool"),
+        isWirelessPool=dict(type="bool"),
+        isIpDirectedBroadcast=dict(type="bool"),
+        isCommonPool=dict(type="bool"),
+        isBridgeModeVm=dict(type="bool"),
+        poolType=dict(type="str"),
+    )
+)
 
-required_if = [
-]
+required_if = []
 required_one_of = []
 mutually_exclusive = []
 required_together = []
@@ -83,39 +87,63 @@ class SdaVirtualNetworkIpPool(object):
 
     def get_all_params(self, name=None, id=None):
         new_object_params = {}
-        new_object_params['siteNameHierarchy'] = self.new_object.get('site_name_hierarchy')
-        new_object_params['virtual_network_name'] = self.new_object.get('virtualNetworkName') or \
-            self.new_object.get('virtual_network_name')
-        new_object_params['ip_pool_name'] = self.new_object.get('ipPoolName') or \
-            self.new_object.get('ip_pool_name')
+        new_object_params["siteNameHierarchy"] = self.new_object.get(
+            "site_name_hierarchy"
+        )
+        new_object_params["virtual_network_name"] = self.new_object.get(
+            "virtualNetworkName"
+        ) or self.new_object.get("virtual_network_name")
+        new_object_params["ip_pool_name"] = self.new_object.get(
+            "ipPoolName"
+        ) or self.new_object.get("ip_pool_name")
         return new_object_params
 
     def create_params(self):
         new_object_params = {}
-        new_object_params['siteNameHierarchy'] = self.new_object.get('siteNameHierarchy')
-        new_object_params['virtualNetworkName'] = self.new_object.get('virtualNetworkName')
-        new_object_params['isLayer2Only'] = self.new_object.get('isLayer2Only')
-        new_object_params['ipPoolName'] = self.new_object.get('ipPoolName')
-        new_object_params['vlanId'] = self.new_object.get('vlanId')
-        new_object_params['vlanName'] = self.new_object.get('vlanName')
-        new_object_params['autoGenerateVlanName'] = self.new_object.get('autoGenerateVlanName')
-        new_object_params['trafficType'] = self.new_object.get('trafficType')
-        new_object_params['scalableGroupName'] = self.new_object.get('scalableGroupName')
-        new_object_params['isL2FloodingEnabled'] = self.new_object.get('isL2FloodingEnabled')
-        new_object_params['isThisCriticalPool'] = self.new_object.get('isThisCriticalPool')
-        new_object_params['isWirelessPool'] = self.new_object.get('isWirelessPool')
-        new_object_params['isIpDirectedBroadcast'] = self.new_object.get('isIpDirectedBroadcast')
-        new_object_params['isCommonPool'] = self.new_object.get('isCommonPool')
-        new_object_params['isBridgeModeVm'] = self.new_object.get('isBridgeModeVm')
-        new_object_params['poolType'] = self.new_object.get('poolType')
+        new_object_params["siteNameHierarchy"] = self.new_object.get(
+            "siteNameHierarchy"
+        )
+        new_object_params["virtualNetworkName"] = self.new_object.get(
+            "virtualNetworkName"
+        )
+        new_object_params["isLayer2Only"] = self.new_object.get("isLayer2Only")
+        new_object_params["ipPoolName"] = self.new_object.get("ipPoolName")
+        new_object_params["vlanId"] = self.new_object.get("vlanId")
+        new_object_params["vlanName"] = self.new_object.get("vlanName")
+        new_object_params["autoGenerateVlanName"] = self.new_object.get(
+            "autoGenerateVlanName"
+        )
+        new_object_params["trafficType"] = self.new_object.get("trafficType")
+        new_object_params["scalableGroupName"] = self.new_object.get(
+            "scalableGroupName"
+        )
+        new_object_params["isL2FloodingEnabled"] = self.new_object.get(
+            "isL2FloodingEnabled"
+        )
+        new_object_params["isThisCriticalPool"] = self.new_object.get(
+            "isThisCriticalPool"
+        )
+        new_object_params["isWirelessPool"] = self.new_object.get("isWirelessPool")
+        new_object_params["isIpDirectedBroadcast"] = self.new_object.get(
+            "isIpDirectedBroadcast"
+        )
+        new_object_params["isCommonPool"] = self.new_object.get("isCommonPool")
+        new_object_params["isBridgeModeVm"] = self.new_object.get("isBridgeModeVm")
+        new_object_params["poolType"] = self.new_object.get("poolType")
         return new_object_params
 
     def delete_all_params(self):
         new_object_params = {}
-        new_object_params['siteNameHierarchy'] = self.new_object.get('site_name_hierarchy')
-        new_object_params['site_name_hierarchy'] = self.new_object.get('site_name_hierarchy')
-        new_object_params['virtual_network_name'] = self.new_object.get('virtual_network_name')
-        new_object_params['ip_pool_name'] = self.new_object.get('ip_pool_name')
+        new_object_params["siteNameHierarchy"] = self.new_object.get(
+            "site_name_hierarchy"
+        )
+        new_object_params["site_name_hierarchy"] = self.new_object.get(
+            "site_name_hierarchy"
+        )
+        new_object_params["virtual_network_name"] = self.new_object.get(
+            "virtual_network_name"
+        )
+        new_object_params["ip_pool_name"] = self.new_object.get("ip_pool_name")
         return new_object_params
 
     def get_object_by_name(self, name, is_absent=False):
@@ -128,14 +156,14 @@ class SdaVirtualNetworkIpPool(object):
                 params=self.get_all_params(name=name),
             )
             if isinstance(items, dict):
-                if 'response' in items:
-                    items = items.get('response')
+                if "response" in items:
+                    items = items.get("response")
                 if isinstance(items, dict) and items.get("status") == "failed":
                     if is_absent:
                         raise AnsibleSDAException(response=items)
                     result = None
                     return result
-            result = get_dict_result(items, 'name', name)
+            result = get_dict_result(items, "name", name)
         except Exception:
             if is_absent:
                 raise
@@ -150,7 +178,11 @@ class SdaVirtualNetworkIpPool(object):
     def exists(self, is_absent=False):
         name = self.new_object.get("name")
         prev_obj = self.get_object_by_name(name, is_absent=is_absent)
-        it_exists = prev_obj is not None and isinstance(prev_obj, dict) and prev_obj.get("status") != "failed"
+        it_exists = (
+            prev_obj is not None
+            and isinstance(prev_obj, dict)
+            and prev_obj.get("status") != "failed"
+        )
         return (it_exists, prev_obj)
 
     def requires_update(self, current_obj):
@@ -179,9 +211,12 @@ class SdaVirtualNetworkIpPool(object):
         ]
         # Method 1. Params present in request (Ansible) obj are the same as the current (ISE) params
         # If any does not have eq params, it requires update
-        return any(not dnac_compare_equality(current_obj.get(dnac_param),
-                                             requested_obj.get(ansible_param))
-                   for (dnac_param, ansible_param) in obj_params)
+        return any(
+            not dnac_compare_equality(
+                current_obj.get(dnac_param), requested_obj.get(ansible_param)
+            )
+            for (dnac_param, ansible_param) in obj_params
+        )
 
     def create(self):
         result = self.dnac.exec(
@@ -191,8 +226,8 @@ class SdaVirtualNetworkIpPool(object):
             op_modifies=True,
         )
         if isinstance(result, dict):
-            if 'response' in result:
-                result = result.get('response')
+            if "response" in result:
+                result = result.get("response")
             if isinstance(result, dict) and result.get("status") == "failed":
                 raise AnsibleSDAException(response=result)
         return result
@@ -212,7 +247,9 @@ class SdaVirtualNetworkIpPool(object):
 class ActionModule(ActionBase):
     def __init__(self, *args, **kwargs):
         if not ANSIBLE_UTILS_IS_INSTALLED:
-            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
+            raise AnsibleActionFail(
+                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
+            )
         super(ActionModule, self).__init__(*args, **kwargs)
         self._supports_async = False
         self._supports_check_mode = False
@@ -272,7 +309,9 @@ class ActionModule(ActionBase):
                 else:
                     dnac.object_already_absent()
             except AnsibleSDAException as e:
-                dnac.fail_json("Could not get object to be delete {e}".format(e=e._response))
+                dnac.fail_json(
+                    "Could not get object to be delete {e}".format(e=e._response)
+                )
 
         self._result.update(dict(dnac_response=response))
         self._result.update(dnac.exit_json())
