@@ -7,11 +7,13 @@
 DOCUMENTATION = r"""
 ---
 module: disasterrecovery_system_operationstatus_info
-short_description: Information module for Disasterrecovery System Operationstatus
+short_description: Information module for Disasterrecovery
+  System Operationstatus
 description:
-- Get all Disasterrecovery System Operationstatus.
-- Returns the status of Disaster Recovery operation performed on the system.
-version_added: '4.0.0'
+  - Get all Disasterrecovery System Operationstatus.
+  - Returns the status of Disaster Recovery operation
+    performed on the system.
+version_added: '6.16.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
 author: Rafael Campos (@racampos)
@@ -20,18 +22,17 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.9
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 notes:
   - SDK Method used are
     disaster_recovery.DisasterRecovery.disaster_recovery_operational_status,
-
   - Paths used are
     get /dna/intent/api/v1/disasterrecovery/system/operationstatus,
-
 """
 
 EXAMPLES = r"""
+---
 - name: Get all Disasterrecovery System Operationstatus
   cisco.dnac.disasterrecovery_system_operationstatus_info:
     dnac_host: "{{dnac_host}}"
@@ -41,12 +42,9 @@ EXAMPLES = r"""
     dnac_port: "{{dnac_port}}"
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
-    headers:
-      custom: value
+    headers: "{{my_headers | from_json}}"
   register: result
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
