@@ -7,39 +7,44 @@
 DOCUMENTATION = r"""
 ---
 module: discovery_range_delete
-short_description: Resource module for Discovery Range Delete
+short_description: Resource module for Discovery Range
+  Delete
 description:
-- Manage operation delete of the resource Discovery Range Delete.
-- Stops discovery for the given range and removes them.
+  - Manage operation delete of the resource Discovery
+    Range Delete.
+  - Stops discovery for the given range and removes
+    them.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   recordsToDelete:
-    description: RecordsToDelete path parameter. Number of records to delete from the
-      starting index.
+    description: RecordsToDelete path parameter. Number
+      of records to delete from the starting index.
     type: int
   startIndex:
-    description: StartIndex path parameter. Starting index for the records.
+    description: StartIndex path parameter. Starting
+      index for the records.
     type: int
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Discovery DeleteDiscoveryBySpecifiedRange
-  description: Complete reference of the DeleteDiscoveryBySpecifiedRange API.
-  link: https://developer.cisco.com/docs/dna-center/#!delete-discovery-by-specified-range
+  - name: Cisco DNA Center documentation for Discovery
+      DeleteDiscoveryBySpecifiedRange
+    description: Complete reference of the DeleteDiscoveryBySpecifiedRange
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!delete-discovery-by-specified-range
 notes:
   - SDK Method used are
     discovery.Discovery.delete_discovery_by_specified_range,
-
   - Paths used are
     delete /dna/intent/api/v1/discovery/{startIndex}/{recordsToDelete},
-
 """
 
 EXAMPLES = r"""
+---
 - name: Delete all
   cisco.dnac.discovery_range_delete:
     dnac_host: "{{dnac_host}}"
@@ -51,7 +56,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     recordsToDelete: 0
     startIndex: 0
-
 """
 RETURN = r"""
 dnac_response:
