@@ -9,8 +9,9 @@ DOCUMENTATION = r"""
 module: dnac_packages_info
 short_description: Information module for Dnac Packages
 description:
-- Get all Dnac Packages.
-- Provides information such as name, version of packages installed on the DNA center.
+  - Get all Dnac Packages.
+  - Provides information such as name, version of packages
+    installed on the Catalyst center.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -20,22 +21,23 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Platform CiscoDNACenterPackagesSummary
-  description: Complete reference of the CiscoDNACenterPackagesSummary API.
-  link: https://developer.cisco.com/docs/dna-center/#!cisco-dna-center-packages-summary
+  - name: Cisco DNA Center documentation for Platform
+      CiscoCatalystCenterPackagesSummary
+    description: Complete reference of the CiscoCatalystCenterPackagesSummary
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!cisco-catalyst-center-packages-summary
 notes:
   - SDK Method used are
-    platform.Platform.cisco_dna_center_packages_summary,
-
+    platform.Platform.cisco_catalyst_center_packages_summary,
   - Paths used are
     get /dna/intent/api/v1/dnac-packages,
-
 """
 
 EXAMPLES = r"""
+---
 - name: Get all Dnac Packages
   cisco.dnac.dnac_packages_info:
     dnac_host: "{{dnac_host}}"
@@ -47,7 +49,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     headers: "{{my_headers | from_json}}"
   register: result
-
 """
 RETURN = r"""
 dnac_response:
