@@ -1,13 +1,17 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: event_series_audit_logs_parent_records_info
-short_description: Information module for Event Series Audit Logs Parent Records Info
+short_description: Information module for Event Series
+  Audit Logs Parent Records
 description:
-  - This module represents an alias of the module event_series_audit_logs_parent_records_v1_info
+  - Get all Event Series Audit Logs Parent Records.
+  - Get Parent Audit Log Event instances from the Event-Hub.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -18,124 +22,147 @@ options:
     type: dict
   instanceId:
     description:
-      - InstanceId query parameter. InstanceID of the Audit Log.
+      - InstanceId query parameter. InstanceID of the
+        Audit Log.
     type: str
   name:
     description:
-      - Name query parameter. Audit Log notification event name.
+      - Name query parameter. Audit Log notification
+        event name.
     type: str
   eventId:
     description:
-      - EventId query parameter. Audit Log notification's event ID.
+      - EventId query parameter. Audit Log notification's
+        event ID.
     type: str
   category:
     description:
       - >
-        Category query parameter. Audit Log notification's event category. Supported
-        values INFO, WARN, ERROR,
-        ALERT, TASK_PROGRESS, TASK_FAILURE, TASK_COMPLETE, COMMAND, QUERY, CONVERSATION.
+        Category query parameter. Audit Log notification's
+        event category. Supported values INFO, WARN,
+        ERROR, ALERT, TASK_PROGRESS, TASK_FAILURE, TASK_COMPLETE,
+        COMMAND, QUERY, CONVERSATION.
     type: str
   severity:
     description:
-      - Severity query parameter. Audit Log notification's event severity. Supported
-        values 1, 2, 3, 4, 5.
+      - Severity query parameter. Audit Log notification's
+        event severity. Supported values 1, 2, 3, 4,
+        5.
     type: str
   domain:
     description:
-      - Domain query parameter. Audit Log notification's event domain.
+      - Domain query parameter. Audit Log notification's
+        event domain.
     type: str
   subDomain:
     description:
-      - SubDomain query parameter. Audit Log notification's event sub-domain.
+      - SubDomain query parameter. Audit Log notification's
+        event sub-domain.
     type: str
   source:
     description:
-      - Source query parameter. Audit Log notification's event source.
+      - Source query parameter. Audit Log notification's
+        event source.
     type: str
   userId:
     description:
-      - UserId query parameter. Audit Log notification's event userId.
+      - UserId query parameter. Audit Log notification's
+        event userId.
     type: str
   context:
     description:
-      - Context query parameter. Audit Log notification's event correlationId.
+      - Context query parameter. Audit Log notification's
+        event correlationId.
     type: str
   eventHierarchy:
     description:
       - >
-        EventHierarchy query parameter. Audit Log notification's event eventHierarchy.
-        Example "US.CA.San Jose" OR
-        "US.CA" OR "CA.San Jose" - Delimiter for hierarchy separation is ".".
+        EventHierarchy query parameter. Audit Log notification's
+        event eventHierarchy. Example "US.CA.San Jose"
+        OR "US.CA" OR "CA.San Jose" - Delimiter for
+        hierarchy separation is ".".
     type: str
   siteId:
     description:
-      - SiteId query parameter. Audit Log notification's siteId.
+      - SiteId query parameter. Audit Log notification's
+        siteId.
     type: str
   deviceId:
     description:
-      - DeviceId query parameter. Audit Log notification's deviceId.
+      - DeviceId query parameter. Audit Log notification's
+        deviceId.
     type: str
   isSystemEvents:
     description:
-      - IsSystemEvents query parameter. Parameter to filter system generated audit-logs.
+      - IsSystemEvents query parameter. Parameter to
+        filter system generated audit-logs.
     type: bool
   description:
     description:
       - >
-        Description query parameter. String full/partial search - (Provided input
-        string is case insensitively
+        Description query parameter. String full/partial
+        search - (Provided input string is case insensitively
         matched for records).
     type: str
   offset:
     description:
-      - Offset query parameter. Position of a particular Audit Log record in the data.
+      - Offset query parameter. Position of a particular
+        Audit Log record in the data.
     type: float
   limit:
     description:
-      - Limit query parameter. Number of Audit Log records to be returned per page.
+      - >
+        Limit query parameter. Number of Audit Log records
+        to be returned per page. Default is 25 if not
+        specified. Maximum allowed limit is 25.
     type: float
   startTime:
     description:
       - >
-        StartTime query parameter. Start Time in milliseconds since Epoch Eg. 1597950637211
-        (when provided endTime
-        is mandatory).
+        StartTime query parameter. Start Time in milliseconds
+        since Epoch Eg. 1597950637211 (when provided
+        endTime is mandatory).
     type: float
   endTime:
     description:
       - >
-        EndTime query parameter. End Time in milliseconds since Epoch Eg. 1597961437211
-        (when provided startTime is
-        mandatory).
+        EndTime query parameter. End Time in milliseconds
+        since Epoch Eg. 1597961437211 (when provided
+        startTime is mandatory).
     type: float
   sortBy:
     description:
       - >
-        SortBy query parameter. Sort the Audit Logs by certain fields. Supported values
-        are event notification
-        header attributes.
+        SortBy query parameter. Sort the Audit Logs
+        by certain fields. Supported values are event
+        notification header attributes.
     type: str
   order:
     description:
       - >
-        Order query parameter. Order of the sorted Audit Log records. Default value
-        is desc by timestamp. Supported
-        values asc, desc.
+        Order query parameter. Order of the sorted Audit
+        Log records. Default value is desc by timestamp.
+        Supported values asc, desc.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Event Management GetAuditLogParentRecordsV1
-    description: Complete reference of the GetAuditLogParentRecordsV1 API.
+  - name: Cisco DNA Center documentation for Event Management
+      GetAuditLogParentRecords
+    description: Complete reference of the GetAuditLogParentRecords
+      API.
     link: https://developer.cisco.com/docs/dna-center/#!get-audit-log-parent-records
 notes:
-  - SDK Method used are event_management.EventManagement.get_auditlog_parent_records,
-  - Paths used are get /dna/data/api/v1/event/event-series/audit-log/parent-records,
-  - It should be noted that this module is an alias of event_series_audit_logs_parent_records_v1_info
+  - SDK Method used are
+    event_management.EventManagement.get_audit_log_parent_records,
+  - Paths used are
+    get /dna/data/api/v1/event/event-series/audit-log/parent-records,
 """
+
 EXAMPLES = r"""
-- name: Get all Event Series Audit Logs Parent Records Info
+---
+- name: Get all Event Series Audit Logs Parent Records
   cisco.dnac.event_series_audit_logs_parent_records_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
