@@ -4,13 +4,14 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: flexible_report_schedule_info
-short_description: Information module for Flexible Report Schedule Info
+short_description: Information module for Flexible Report
+  Schedule
 description:
-- This module represents an alias of the module flexible_report_schedule_v1_info
+  - Get Flexible Report Schedule by id.
+  - Get flexible report schedule by report id.
 version_added: '6.14.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,27 +22,27 @@ options:
     type: dict
   reportId:
     description:
-    - ReportId path parameter. Id of the report.
+      - ReportId path parameter. Id of the report.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Reports GetFlexibleReportScheduleByReportIdV1
-  description: Complete reference of the GetFlexibleReportScheduleByReportIdV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-flexible-report-schedule-by-report-id
+  - name: Cisco DNA Center documentation for Reports
+      GetFlexibleReportScheduleByReportId
+    description: Complete reference of the GetFlexibleReportScheduleByReportId
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-flexible-report-schedule-by-report-id
 notes:
   - SDK Method used are
-    reports.Reports.get_flexible_report_schedule_by_report_id_v1,
-
+    reports.Reports.get_flexible_report_schedule_by_report_id,
   - Paths used are
     get /dna/data/api/v1/flexible-report/schedule/{reportId},
-  - It should be noted that this module is an alias of flexible_report_schedule_v1_info
-
 """
 
 EXAMPLES = r"""
-- name: Get Flexible Report Schedule Info by id
+---
+- name: Get Flexible Report Schedule by id
   cisco.dnac.flexible_report_schedule_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -53,7 +54,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     reportId: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
