@@ -1,13 +1,20 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: icap_capture_files_id_download_info
-short_description: Information module for Icap Capture Files Id Download Info
+short_description: Information module for Icap Capture
+  Files Id Download
 description:
-  - This module represents an alias of the module icap_capture_files_id_download_v1_info
+  - Get all Icap Capture Files Id Download. - > Downloads
+    a specific ICAP packet capture file. For detailed
+    information about the usage of the API, please refer
+    to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-
+    api-specs/blob/main/Assurance/CE_Cat_Center_Org-icap-1.0.0-resolved.yaml.
 version_added: '6.17.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -18,25 +25,29 @@ options:
     type: dict
   id:
     description:
-      - Id path parameter. The name of the packet capture file, as given by the GET
-        /captureFiles API response.
+      - Id path parameter. The name of the packet capture
+        file, as given by the GET /captureFiles API
+        response.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Sensors DownloadsASpecificICAPPacketCaptureFileV1
-    description: Complete reference of the DownloadsASpecificICAPPacketCaptureFileV1
+  - name: Cisco DNA Center documentation for Sensors
+      DownloadsASpecificICAPPacketCaptureFile
+    description: Complete reference of the DownloadsASpecificICAPPacketCaptureFile
       API.
-    link:
-      https://developer.cisco.com/docs/dna-center/#!downloads-a-specific-icap-packet-capture-file
+    link: https://developer.cisco.com/docs/dna-center/#!downloads-a-specific-icap-packet-capture-file
 notes:
-  - SDK Method used are sensors.Sensors.downloads_a_specific_i_cap_packet_capture_file_v1,
-  - Paths used are get /dna/data/api/v1/icap/captureFiles/{id}/download,
-  - It should be noted that this module is an alias of icap_capture_files_id_download_v1_info
+  - SDK Method used are
+    sensors.Sensors.downloads_a_specific_i_cap_packet_capture_file,
+  - Paths used are
+    get /dna/data/api/v1/icap/captureFiles/{id}/download,
 """
+
 EXAMPLES = r"""
-- name: Get all Icap Capture Files Id Download Info
+---
+- name: Get all Icap Capture Files Id Download
   cisco.dnac.icap_capture_files_id_download_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
