@@ -4,13 +4,15 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: network_device_interface_neighbor_info
-short_description: Information module for Network Device Interface Neighbor Info
+short_description: Information module for Network Device
+  Interface Neighbor
 description:
-- This module represents an alias of the module network_device_interface_neighbor_v1_info
+  - Get all Network Device Interface Neighbor.
+  - Get connected device detail for given deviceUuid
+    and interfaceUuid.
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,31 +23,32 @@ options:
     type: dict
   deviceUuid:
     description:
-    - DeviceUuid path parameter. Instanceuuid of Device.
+      - DeviceUuid path parameter. Instanceuuid of Device.
     type: str
   interfaceUuid:
     description:
-    - InterfaceUuid path parameter. Instanceuuid of interface.
+      - InterfaceUuid path parameter. Instanceuuid of
+        interface.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Devices GetConnectedDeviceDetailV1
-  description: Complete reference of the GetConnectedDeviceDetailV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-connected-device-detail
+  - name: Cisco DNA Center documentation for Devices
+      GetConnectedDeviceDetail
+    description: Complete reference of the GetConnectedDeviceDetail
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-connected-device-detail
 notes:
   - SDK Method used are
-    devices.Devices.get_connected_device_detail_v1,
-
+    devices.Devices.get_connected_device_detail,
   - Paths used are
     get /dna/intent/api/v1/network-device/{deviceUuid}/interface/{interfaceUuid}/neighbor,
-  - It should be noted that this module is an alias of network_device_interface_neighbor_v1_info
-
 """
 
 EXAMPLES = r"""
-- name: Get all Network Device Interface Neighbor Info
+---
+- name: Get all Network Device Interface Neighbor
   cisco.dnac.network_device_interface_neighbor_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -58,7 +61,6 @@ EXAMPLES = r"""
     deviceUuid: string
     interfaceUuid: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
