@@ -1,13 +1,18 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: network_devices_assigned_to_site_count_info
-short_description: Information module for Network Devices Assigned To Site Count Info
+short_description: Information module for Network Devices
+  Assigned To Site Count
 description:
-  - This module represents an alias of the module network_devices_assigned_to_site_count_v1_info
+  - Get all Network Devices Assigned To Site Count.
+  - Get all network devices count under the given site
+    in the network hierarchy.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -18,24 +23,28 @@ options:
     type: dict
   siteId:
     description:
-      - SiteId query parameter. Site Id. It must be area Id or building Id or floor
-        Id.
+      - SiteId query parameter. Site Id. It must be
+        area Id or building Id or floor Id.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Site Design GetSiteAssignedNetworkDevicesCountV1
-    description: Complete reference of the GetSiteAssignedNetworkDevicesCountV1 API.
-    link:
-      https://developer.cisco.com/docs/dna-center/#!get-site-assigned-network-devices-count
+  - name: Cisco DNA Center documentation for Site Design
+      GetSiteAssignedNetworkDevicesCount
+    description: Complete reference of the GetSiteAssignedNetworkDevicesCount
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-site-assigned-network-devices-count
 notes:
-  - SDK Method used are site_design.SiteDesign.get_site_assigned_network_devices_count_v1,
-  - Paths used are get /dna/intent/api/v1/networkDevices/assignedToSite/count,
-  - It should be noted that this module is an alias of network_devices_assigned_to_site_count_v1_info
+  - SDK Method used are
+    site_design.SiteDesign.get_site_assigned_network_devices_count,
+  - Paths used are
+    get /dna/intent/api/v1/networkDevices/assignedToSite/count,
 """
+
 EXAMPLES = r"""
-- name: Get all Network Devices Assigned To Site Count Info
+---
+- name: Get all Network Devices Assigned To Site Count
   cisco.dnac.network_devices_assigned_to_site_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
