@@ -1,13 +1,18 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: network_devices_not_assigned_to_site_info
-short_description: Information module for Network Devices Not Assigned To Site Info
+short_description: Information module for Network Devices
+  Not Assigned To Site
 description:
-  - This module represents an alias of the module network_devices_not_assigned_to_site_v1_info
+  - Get all Network Devices Not Assigned To Site.
+  - Get network devices that are not assigned to any
+    site.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -18,29 +23,35 @@ options:
     type: dict
   offset:
     description:
-      - Offset query parameter. The first record to show for this page; the first
-        record is numbered 1.
+      - Offset query parameter. The first record to
+        show for this page; the first record is numbered
+        1.
     type: float
   limit:
     description:
-      - Limit query parameter. The number of records to show for this page;The minimum
-        is 1, and the maximum is 500.
+      - Limit query parameter. The number of records
+        to show for this page;The minimum is 1, and
+        the maximum is 500.
     type: float
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Site Design GetSiteNotAssignedNetworkDevicesV1
-    description: Complete reference of the GetSiteNotAssignedNetworkDevicesV1 API.
-    link:
-      https://developer.cisco.com/docs/dna-center/#!get-site-not-assigned-network-devices
+  - name: Cisco DNA Center documentation for Site Design
+      GetSiteNotAssignedNetworkDevices
+    description: Complete reference of the GetSiteNotAssignedNetworkDevices
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-site-not-assigned-network-devices
 notes:
-  - SDK Method used are site_design.SiteDesign.get_site_not_assigned_network_devices_v1,
-  - Paths used are get /dna/intent/api/v1/networkDevices/notAssignedToSite,
-  - It should be noted that this module is an alias of network_devices_not_assigned_to_site_v1_info
+  - SDK Method used are
+    site_design.SiteDesign.get_site_not_assigned_network_devices,
+  - Paths used are
+    get /dna/intent/api/v1/networkDevices/notAssignedToSite,
 """
+
 EXAMPLES = r"""
-- name: Get all Network Devices Not Assigned To Site Info
+---
+- name: Get all Network Devices Not Assigned To Site
   cisco.dnac.network_devices_not_assigned_to_site_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
