@@ -4,13 +4,17 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: reports_view_group_view_info
-short_description: Information module for Reports View Group View Info
+short_description: Information module for Reports View
+  Group View
 description:
-- This module represents an alias of the module reports_view_group_view_v1_info
+  - Get Reports View Group View by id. - > Gives complete
+    information of the view that is required to configure
+    a report. Use "Get views for a given view group"
+    API to get the viewIds required as a query param
+    for this API for available views.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,31 +25,31 @@ options:
     type: dict
   viewGroupId:
     description:
-    - ViewGroupId path parameter. ViewGroupId of viewgroup.
+      - ViewGroupId path parameter. ViewGroupId of viewgroup.
     type: str
   viewId:
     description:
-    - ViewId path parameter. View id of view.
+      - ViewId path parameter. View id of view.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Reports GetViewDetailsForAGivenViewGroup_ViewV1
-  description: Complete reference of the GetViewDetailsForAGivenViewGroup_ViewV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-view-details-for-a-given-view-group-view
+  - name: Cisco DNA Center documentation for Reports
+      GetViewDetailsForAGivenViewGroup_View
+    description: Complete reference of the GetViewDetailsForAGivenViewGroup_View
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-view-details-for-a-given-view-group-view
 notes:
   - SDK Method used are
     reports.Reports.get_view_details_for_a_given_view_group_and_view,
-
   - Paths used are
     get /dna/intent/api/v1/data/view-groups/{viewGroupId}/views/{viewId},
-  - It should be noted that this module is an alias of reports_view_group_view_v1_info
-
 """
 
 EXAMPLES = r"""
-- name: Get Reports View Group View Info by id
+---
+- name: Get Reports View Group View by id
   cisco.dnac.reports_view_group_view_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -58,7 +62,6 @@ EXAMPLES = r"""
     viewGroupId: string
     viewId: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
