@@ -4,13 +4,15 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: sda_fabric_zones_info
-short_description: Information module for Sda Fabric Zones Info
+short_description: Information module for Sda Fabric
+  Zones
 description:
-- This module represents an alias of the module sda_fabric_zones_v1_info
+  - Get all Sda Fabric Zones.
+  - Returns a list of fabric zones that match the provided
+    query parameters.
 version_added: '6.14.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,41 +23,43 @@ options:
     type: dict
   id:
     description:
-    - Id query parameter. ID of the fabric zone.
+      - Id query parameter. ID of the fabric zone.
     type: str
   siteId:
     description:
-    - SiteId query parameter. ID of the network hierarchy associated with the fabric zone.
+      - SiteId query parameter. ID of the network hierarchy
+        associated with the fabric zone.
     type: str
   offset:
     description:
-    - Offset query parameter. Starting record for pagination.
+      - Offset query parameter. Starting record for
+        pagination.
     type: float
   limit:
     description:
-    - >
-      Limit query parameter. Maximum number of records to return. The maximum number of objects supported in a
-      single request is 500.
+      - >
+        Limit query parameter. Maximum number of records
+        to return. The maximum number of objects supported
+        in a single request is 500.
     type: float
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for SDA GetFabricZonesV1
-  description: Complete reference of the GetFabricZonesV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-fabric-zones
+  - name: Cisco DNA Center documentation for SDA GetFabricZones
+    description: Complete reference of the GetFabricZones
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-fabric-zones
 notes:
   - SDK Method used are
-    sda.Sda.get_fabric_zones_v1,
-
+    sda.Sda.get_fabric_zones,
   - Paths used are
     get /dna/intent/api/v1/sda/fabricZones,
-  - It should be noted that this module is an alias of sda_fabric_zones_v1_info
-
 """
 
 EXAMPLES = r"""
-- name: Get all Sda Fabric Zones Info
+---
+- name: Get all Sda Fabric Zones
   cisco.dnac.sda_fabric_zones_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -70,7 +74,6 @@ EXAMPLES = r"""
     offset: 0
     limit: 0
   register: result
-
 """
 RETURN = r"""
 dnac_response:
