@@ -1,13 +1,18 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: sda_fabrics_vlan_to_ssids_info
-short_description: Information module for Sda Fabrics Vlan To Ssids Info
+short_description: Information module for Sda Fabrics
+  Vlan To Ssids
 description:
-  - This module represents an alias of the module sda_fabrics_vlan_to_ssids_v1_info
+  - Get all Sda Fabrics Vlan To Ssids.
+  - It will return all vlan to SSID mapping across all
+    the fabric site.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -19,31 +24,34 @@ options:
   limit:
     description:
       - >
-        Limit query parameter. Return only this many IP Pool to SSID Mapping. Default
-        is 500 if not specified.
-        Maximum allowed limit is 500.
+        Limit query parameter. Return only this many
+        IP Pool to SSID Mapping. Default is 500 if not
+        specified. Maximum allowed limit is 500.
     type: float
   offset:
     description:
-      - Offset query parameter. Number of records to skip for pagination.
+      - Offset query parameter. Number of records to
+        skip for pagination.
     type: float
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Fabric Wireless ReturnsAllTheFabricSitesThatHaveVLANToSSIDMappingV1
-    description: Complete reference of the ReturnsAllTheFabricSitesThatHaveVLANToSSIDMappingV1
+  - name: Cisco DNA Center documentation for Fabric
+      Wireless ReturnsAllTheFabricSitesThatHaveVLANToSSIDMapping
+    description: Complete reference of the ReturnsAllTheFabricSitesThatHaveVLANToSSIDMapping
       API.
-    link:
-      https://developer.cisco.com/docs/dna-center/#!returns-all-the-fabric-sites-that-have-vlan-to-ssid-mapping
+    link: https://developer.cisco.com/docs/dna-center/#!returns-all-the-fabric-sites-that-have-vlan-to-ssid-mapping
 notes:
   - SDK Method used are
-    fabric_wireless.FabricWireless.returns_all_the_fabric_sites_that_have_vlan_to_ssid_mapping_v1,
-  - Paths used are get /dna/intent/api/v1/sda/fabrics/vlanToSsids,
-  - It should be noted that this module is an alias of sda_fabrics_vlan_to_ssids_v1_info
+    fabric_wireless.FabricWireless.returns_all_the_fabric_sites_that_have_vlan_to_ssid_mapping,
+  - Paths used are
+    get /dna/intent/api/v1/sda/fabrics/vlanToSsids,
 """
+
 EXAMPLES = r"""
-- name: Get all Sda Fabrics Vlan To Ssids Info
+---
+- name: Get all Sda Fabrics Vlan To Ssids
   cisco.dnac.sda_fabrics_vlan_to_ssids_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
