@@ -7,57 +7,65 @@
 DOCUMENTATION = r"""
 ---
 module: sda_virtual_network_v2
-short_description: Resource module for Sda Virtual Network V2
+short_description: Resource module for Sda Virtual Network
+  V2
 description:
-- Manage operations create, update and delete of the resource Sda Virtual Network V2.
-- Add virtual network with scalable groups at global level.
-- Delete virtual network with scalable groups.
-- Update virtual network with scalable groups.
+  - Manage operations create, update and delete of the
+    resource Sda Virtual Network V2.
+  - Add virtual network with scalable groups at global
+    level.
+  - Delete virtual network with scalable groups.
+  - Update virtual network with scalable groups.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   isGuestVirtualNetwork:
-    description: Guest Virtual Network enablement flag, default value is False.
+    description: Guest Virtual Network enablement flag,
+      default value is False.
     type: bool
   scalableGroupNames:
-    description: Scalable Group to be associated to virtual network.
+    description: Scalable Group to be associated to
+      virtual network.
     elements: str
     type: list
   vManageVpnId:
     description: VManage vpn id for SD-WAN.
     type: str
   virtualNetworkName:
-    description: Virtual Network Name to be assigned at global level.
+    description: Virtual Network Name to be assigned
+      at global level.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for SDA AddVirtualNetworkWithScalableGroupsV1
-  description: Complete reference of the AddVirtualNetworkWithScalableGroupsV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!add-virtual-network-with-scalable-groups
-- name: Cisco DNA Center documentation for SDA DeleteVirtualNetworkWithScalableGroupsV1
-  description: Complete reference of the DeleteVirtualNetworkWithScalableGroupsV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!delete-virtual-network-with-scalable-groups
-- name: Cisco DNA Center documentation for SDA UpdateVirtualNetworkWithScalableGroupsV1
-  description: Complete reference of the UpdateVirtualNetworkWithScalableGroupsV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!update-virtual-network-with-scalable-groups
+  - name: Cisco DNA Center documentation for SDA AddVirtualNetworkWithScalableGroups
+    description: Complete reference of the AddVirtualNetworkWithScalableGroups
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!add-virtual-network-with-scalable-groups
+  - name: Cisco DNA Center documentation for SDA DeleteVirtualNetworkWithScalableGroups
+    description: Complete reference of the DeleteVirtualNetworkWithScalableGroups
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!delete-virtual-network-with-scalable-groups
+  - name: Cisco DNA Center documentation for SDA UpdateVirtualNetworkWithScalableGroups
+    description: Complete reference of the UpdateVirtualNetworkWithScalableGroups
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!update-virtual-network-with-scalable-groups
 notes:
   - SDK Method used are
-    sda.Sda.add_virtual_network_with_scalable_groups_v1,
-    sda.Sda.delete_virtual_network_with_scalable_groups_v1,
-    sda.Sda.update_virtual_network_with_scalable_groups_v1,
-
+    sda.Sda.add_virtual_network_with_scalable_groups,
+    sda.Sda.delete_virtual_network_with_scalable_groups,
+    sda.Sda.update_virtual_network_with_scalable_groups,
   - Paths used are
     post /dna/intent/api/v1/virtual-network,
     delete /dna/intent/api/v1/virtual-network,
     put /dna/intent/api/v1/virtual-network,
-
 """
 
 EXAMPLES = r"""
+---
 - name: Create
   cisco.dnac.sda_virtual_network_v2:
     dnac_host: "{{dnac_host}}"
@@ -70,10 +78,9 @@ EXAMPLES = r"""
     state: present
     isGuestVirtualNetwork: true
     scalableGroupNames:
-    - string
+      - string
     vManageVpnId: string
     virtualNetworkName: string
-
 - name: Delete all
   cisco.dnac.sda_virtual_network_v2:
     dnac_host: "{{dnac_host}}"
@@ -85,7 +92,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: absent
     virtualNetworkName: string
-
 - name: Update all
   cisco.dnac.sda_virtual_network_v2:
     dnac_host: "{{dnac_host}}"
@@ -98,10 +104,9 @@ EXAMPLES = r"""
     state: present
     isGuestVirtualNetwork: true
     scalableGroupNames:
-    - string
+      - string
     vManageVpnId: string
     virtualNetworkName: string
-
 """
 RETURN = r"""
 dnac_response:
