@@ -1,13 +1,22 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: site_kpi_summaries_top_n_analytics
-short_description: Resource module for Site Kpi Summaries Top N Analytics
+short_description: Resource module for Sitekpisummaries
+  Topnanalytics
 description:
-  - This module represents an alias of the module site_kpi_summaries_top_n_analytics_v1
+  - Manage operation create of the resource Sitekpisummaries
+    Topnanalytics. - > Gets the Top N entites related
+    based on site analytics for a given kpi type. For
+    detailed information about the usage of the API,
+    please refer to the Open API specification document
+    - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
+    SiteKpiSummaries-1.0.0-resolved.yaml.
 version_added: '6.17.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -17,7 +26,8 @@ options:
     description: End Time.
     type: int
   filters:
-    description: Site Kpi Summaries Top N Analytics's filters.
+    description: Site Kpi Summaries Top N Analytics's
+      filters.
     elements: dict
     suboptions:
       key:
@@ -41,22 +51,24 @@ options:
     description: Top N.
     type: int
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Sites SubmitRequestForTopNEntitiesRelatedToSiteAnalyticsV1
-    description: Complete reference of the SubmitRequestForTopNEntitiesRelatedToSiteAnalyticsV1
+  - name: Cisco DNA Center documentation for Sites SubmitRequestForTopNEntitiesRelatedToSiteAnalytics
+    description: Complete reference of the SubmitRequestForTopNEntitiesRelatedToSiteAnalytics
       API.
-    link:
-      https://developer.cisco.com/docs/dna-center/#!submit-request-for-top-n-entities-related-to-site-analytics
+    link: https://developer.cisco.com/docs/dna-center/#!submit-request-for-top-n-entities-related-to-site-analytics
 notes:
-  - SDK Method used are sites.Sites.submit_request_for_top_n_entities_related_to_site_analytics_v1,
-  - Paths used are post /dna/data/api/v1/siteKpiSummaries/topNAnalytics,
-  - It should be noted that this module is an alias of site_kpi_summaries_top_n_analytics_v1
+  - SDK Method used are
+    sites.Sites.submit_request_for_top_n_entities_related_to_site_analytics,
+  - Paths used are
+    post /dna/data/api/v1/siteKpiSummaries/topNAnalytics,
 """
+
 EXAMPLES = r"""
+---
 - name: Create
-  cisco.dnac.site_kpi_summaries_top_n_analytics:
+  cisco.dnac.siteKpiSummaries_topNAnalytics:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
     dnac_password: "{{dnac_password}}"
