@@ -1,13 +1,20 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: sites_banner_settings_info
-short_description: Information module for Sites Banner Settings Info
+short_description: Information module for Sites Banner
+  Settings
 description:
-  - This module represents an alias of the module sites_banner_settings_v1_info
+  - Get all Sites Banner Settings. - > Retrieve banner
+    settings for a site; `null` values indicate that
+    the setting will be inherited from the parent site;
+    empty objects `{}` indicate that the setting is
+    unset at a site.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -23,27 +30,32 @@ options:
   _inherited:
     description:
       - >
-        _inherited query parameter. Include settings explicitly set for this site
-        and settings inherited from sites
-        higher in the site hierarchy; when `false`, `null` values indicate that the
-        site inherits that setting from
-        the parent site or a site higher in the site hierarchy.
+        _inherited query parameter. Include settings
+        explicitly set for this site and settings inherited
+        from sites higher in the site hierarchy; when
+        `false`, `null` values indicate that the site
+        inherits that setting from the parent site or
+        a site higher in the site hierarchy.
     type: bool
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Network Settings RetrieveBannerSettingsForASiteV1
-    description: Complete reference of the RetrieveBannerSettingsForASiteV1 API.
-    link:
-      https://developer.cisco.com/docs/dna-center/#!retrieve-banner-settings-for-a-site
+  - name: Cisco DNA Center documentation for Network
+      Settings RetrieveBannerSettingsForASite
+    description: Complete reference of the RetrieveBannerSettingsForASite
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!retrieve-banner-settings-for-a-site
 notes:
-  - SDK Method used are network_settings.NetworkSettings.retrieve_banner_settings_for_a_site_v1,
-  - Paths used are get /dna/intent/api/v1/sites/{id}/bannerSettings,
-  - It should be noted that this module is an alias of sites_banner_settings_v1_info
+  - SDK Method used are
+    network_settings.NetworkSettings.retrieve_banner_settings_for_a_site,
+  - Paths used are
+    get /dna/intent/api/v1/sites/{id}/bannerSettings,
 """
+
 EXAMPLES = r"""
-- name: Get all Sites Banner Settings Info
+---
+- name: Get all Sites Banner Settings
   cisco.dnac.sites_banner_settings_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
