@@ -1,13 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: sites_count_info
-short_description: Information module for Sites Count Info
+short_description: Information module for Sites Count
 description:
-  - This module represents an alias of the module sites_count_v1_info
+  - Get all Sites Count.
+  - Get sites count.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,19 +24,24 @@ options:
       - Name query parameter. Site name.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Site Design GetSitesCountV1
-    description: Complete reference of the GetSitesCountV1 API.
+  - name: Cisco DNA Center documentation for Site Design
+      GetSitesCount
+    description: Complete reference of the GetSitesCount
+      API.
     link: https://developer.cisco.com/docs/dna-center/#!get-sites-count
 notes:
-  - SDK Method used are site_design.SiteDesign.get_sites_count_v1,
-  - Paths used are get /dna/intent/api/v1/sites/count,
-  - It should be noted that this module is an alias of sites_count_v1_info
+  - SDK Method used are
+    site_design.SiteDesign.get_sites_count,
+  - Paths used are
+    get /dna/intent/api/v1/sites/count,
 """
+
 EXAMPLES = r"""
-- name: Get all Sites Count Info
+---
+- name: Get all Sites Count
   cisco.dnac.sites_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
