@@ -67,25 +67,25 @@ EXAMPLES = """
 # Collect only the config and default facts
 - cisco.iosxr.iosxr_facts:
     gather_subset:
-    - config
+      - config
 
 # Do not collect hardware facts
 - cisco.iosxr.iosxr_facts:
     gather_subset:
-    - '!hardware'
+      - '!hardware'
 
 # Collect only the lacp facts
 - cisco.iosxr.iosxr_facts:
     gather_subset:
-    - '!all'
-    - '!min'
+      - '!all'
+      - '!min'
     gather_network_resources:
-    - lacp
+      - lacp
 
 # Do not collect lacp_interfaces facts
 - cisco.iosxr.iosxr_facts:
     gather_network_resources:
-    - '!lacp_interfaces'
+      - '!lacp_interfaces'
 
 # Collect lacp and minimal default facts
 - cisco.iosxr.iosxr_facts:
@@ -95,11 +95,11 @@ EXAMPLES = """
 # Collect only the interfaces facts
 - cisco.iosxr.iosxr_facts:
     gather_subset:
-    - '!all'
-    - '!min'
+      - '!all'
+      - '!min'
     gather_network_resources:
-    - interfaces
-    - l2_interfaces
+      - interfaces
+      - l2_interfaces
 """
 
 RETURN = """
@@ -147,6 +147,10 @@ ansible_net_memtotal_mb:
   description: The total memory on the remote device in Mb
   returned: when hardware is configured
   type: int
+ansible_net_cpu_utilization:
+  description: The current CPU utilization of the device
+  returned: when hardware is configured
+  type: dict
 
 # config
 ansible_net_config:
@@ -168,7 +172,8 @@ ansible_net_interfaces:
   returned: when interfaces is configured
   type: dict
 ansible_net_neighbors:
-  description: The list of LLDP neighbors from the remote device
+  description: The list of LLDP and CDP neighbors from the remote device. If both,
+      CDP and LLDP neighbor data is present on one port, CDP is preferred.
   returned: when interfaces is configured
   type: dict
 
