@@ -72,13 +72,17 @@ class NetworksWirelessSettings(object):
     def update_all_params(self):
         new_object_params = {}
         if self.new_object.get('ipv6BridgeEnabled') is not None or self.new_object.get('ipv6_bridge_enabled') is not None:
-            new_object_params['ipv6BridgeEnabled'] = self.new_object.get('ipv6BridgeEnabled')
+            new_object_params['ipv6BridgeEnabled'] = self.new_object.get(
+                'ipv6BridgeEnabled')
         if self.new_object.get('ledLightsOn') is not None or self.new_object.get('led_lights_on') is not None:
-            new_object_params['ledLightsOn'] = self.new_object.get('ledLightsOn')
+            new_object_params['ledLightsOn'] = self.new_object.get(
+                'ledLightsOn')
         if self.new_object.get('locationAnalyticsEnabled') is not None or self.new_object.get('location_analytics_enabled') is not None:
-            new_object_params['locationAnalyticsEnabled'] = self.new_object.get('locationAnalyticsEnabled')
+            new_object_params['locationAnalyticsEnabled'] = self.new_object.get(
+                'locationAnalyticsEnabled')
         if self.new_object.get('meshingEnabled') is not None or self.new_object.get('meshing_enabled') is not None:
-            new_object_params['meshingEnabled'] = self.new_object.get('meshingEnabled')
+            new_object_params['meshingEnabled'] = self.new_object.get(
+                'meshingEnabled')
         if self.new_object.get('namedVlans') is not None or self.new_object.get('named_vlans') is not None:
             new_object_params['namedVlans'] = self.new_object.get('namedVlans') or \
                 self.new_object.get('named_vlans')
@@ -119,7 +123,8 @@ class NetworksWirelessSettings(object):
         prev_obj = None
         id_exists = False
         name_exists = False
-        o_id = self.new_object.get("networkId") or self.new_object.get("network_id")
+        o_id = self.new_object.get(
+            "networkId") or self.new_object.get("network_id")
         name = self.new_object.get("name")
         if o_id:
             prev_obj = self.get_object_by_name(o_id)
