@@ -63,7 +63,8 @@ argument_spec.update(dict(
 ))
 
 required_if = [
-    ("state", "present", ["configTemplateId", "name", "organizationId", "portId", "profileId"], True),
+    ("state", "present", ["configTemplateId", "name",
+     "organizationId", "portId", "profileId"], True),
 ]
 required_one_of = []
 mutually_exclusive = []
@@ -152,9 +153,11 @@ class OrganizationsConfigTemplatesSwitchProfilesPorts(object):
         if self.new_object.get('enabled') is not None or self.new_object.get('enabled') is not None:
             new_object_params['enabled'] = self.new_object.get('enabled')
         if self.new_object.get('flexibleStackingEnabled') is not None or self.new_object.get('flexible_stacking_enabled') is not None:
-            new_object_params['flexibleStackingEnabled'] = self.new_object.get('flexibleStackingEnabled')
+            new_object_params['flexibleStackingEnabled'] = self.new_object.get(
+                'flexibleStackingEnabled')
         if self.new_object.get('isolationEnabled') is not None or self.new_object.get('isolation_enabled') is not None:
-            new_object_params['isolationEnabled'] = self.new_object.get('isolationEnabled')
+            new_object_params['isolationEnabled'] = self.new_object.get(
+                'isolationEnabled')
         if self.new_object.get('linkNegotiation') is not None or self.new_object.get('link_negotiation') is not None:
             new_object_params['linkNegotiation'] = self.new_object.get('linkNegotiation') or \
                 self.new_object.get('link_negotiation')
@@ -173,7 +176,8 @@ class OrganizationsConfigTemplatesSwitchProfilesPorts(object):
             new_object_params['profile'] = self.new_object.get('profile') or \
                 self.new_object.get('profile')
         if self.new_object.get('rstpEnabled') is not None or self.new_object.get('rstp_enabled') is not None:
-            new_object_params['rstpEnabled'] = self.new_object.get('rstpEnabled')
+            new_object_params['rstpEnabled'] = self.new_object.get(
+                'rstpEnabled')
         if self.new_object.get('stickyMacAllowList') is not None or self.new_object.get('sticky_mac_allow_list') is not None:
             new_object_params['stickyMacAllowList'] = self.new_object.get('stickyMacAllowList') or \
                 self.new_object.get('sticky_mac_allow_list')
@@ -181,7 +185,8 @@ class OrganizationsConfigTemplatesSwitchProfilesPorts(object):
             new_object_params['stickyMacAllowListLimit'] = self.new_object.get('stickyMacAllowListLimit') or \
                 self.new_object.get('sticky_mac_allow_list_limit')
         if self.new_object.get('stormControlEnabled') is not None or self.new_object.get('storm_control_enabled') is not None:
-            new_object_params['stormControlEnabled'] = self.new_object.get('stormControlEnabled')
+            new_object_params['stormControlEnabled'] = self.new_object.get(
+                'stormControlEnabled')
         if self.new_object.get('stpGuard') is not None or self.new_object.get('stp_guard') is not None:
             new_object_params['stpGuard'] = self.new_object.get('stpGuard') or \
                 self.new_object.get('stp_guard')
@@ -375,7 +380,8 @@ class ActionModule(ActionBase):
         self._check_argspec()
 
         meraki = MERAKI(self._task.args)
-        obj = OrganizationsConfigTemplatesSwitchProfilesPorts(self._task.args, meraki)
+        obj = OrganizationsConfigTemplatesSwitchProfilesPorts(
+            self._task.args, meraki)
 
         state = self._task.args.get("state")
 
