@@ -19,6 +19,7 @@ module: mso_dhcp_relay_policy_provider
 short_description: Manage DHCP providers in a DHCP Relay policy.
 description:
 - Manage DHCP providers in a DHCP Relay policy on Cisco Multi-Site Orchestrator.
+- This module is only supported on NDO version prior to v4.0.
 author:
 - Jorge Gomez (@jorgegome2307)
 options:
@@ -26,7 +27,7 @@ options:
     description:
     - Name of the DHCP Relay Policy
     type: str
-    required: yes
+    required: true
     aliases: [ name ]
   ip:
     description:
@@ -82,7 +83,6 @@ EXAMPLES = r"""
     application_profile: ansible_test
     endpoint_group: ansible_test
     state: present
-  delegate_to: localhost
 
 - name: Remove a provider to a DHCP Relay Policy
   cisco.mso.mso_dhcp_relay_policy_provider:
@@ -96,7 +96,6 @@ EXAMPLES = r"""
     application_profile: ansible_test
     endpoint_group: ansible_test
     state: absent
-  delegate_to: localhost
 
 - name: Query a provider to a DHCP Relay Policy
   cisco.mso.mso_dhcp_relay_policy_provider:
@@ -110,7 +109,7 @@ EXAMPLES = r"""
     application_profile: ansible_test
     endpoint_group: ansible_test
     state: query
-  delegate_to: localhost
+  register: query_result
 
 - name: Query all provider of a DHCP Relay Policy
   cisco.mso.mso_dhcp_relay_policy_provider:
@@ -119,7 +118,7 @@ EXAMPLES = r"""
     password: SomeSecretPassword
     dhcp_relay_policy: my_test_dhcp_policy
     state: query
-  delegate_to: localhost
+  register: query_result
 """
 
 RETURN = r"""
