@@ -34,7 +34,7 @@ options:
     description:
     - URI being used to execute API calls.
     type: str
-    required: yes
+    required: true
     aliases: [ uri ]
   content:
     description:
@@ -64,26 +64,25 @@ EXAMPLES = r"""
     method: post
     content:
       {
-          "displayName": "{{ mso_schema | default('ansible_test') }}",
-          "templates": [{
-              "name": "Template_1",
-              "tenantId": "{{ add_tenant.jsondata.id }}",
-              "displayName": "Template_1",
-              "templateSubType": [],
-              "templateType": "stretched-template",
-              "anps": [],
-              "contracts": [],
-              "vrfs": [],
-              "bds": [],
-              "filters": [],
-              "externalEpgs": [],
-              "serviceGraphs": [],
-              "intersiteL3outs": []
-          }],
-          "sites": [],
-          "_updateVersion": 0
+        "displayName": "{{ mso_schema | default('ansible_test') }}",
+        "templates": [{
+          "name": "Template_1",
+          "tenantId": "{{ add_tenant.jsondata.id }}",
+          "displayName": "Template_1",
+          "templateSubType": [],
+          "templateType": "stretched-template",
+          "anps": [],
+          "contracts": [],
+          "vrfs": [],
+          "bds": [],
+          "filters": [],
+          "externalEpgs": [],
+          "serviceGraphs": [],
+          "intersiteL3outs": []
+        }],
+        "sites": [],
+        "_updateVersion": 0
       }
-  delegate_to: localhost
 
 - name: Query schema
   cisco.mso.mso_rest:
@@ -92,7 +91,7 @@ EXAMPLES = r"""
     password: SomeSecretPassword
     path: /mso/api/v1/schemas
     method: get
-  delegate_to: localhost
+  register: query_result
 
 - name: Patch schema (YAML)
   cisco.mso.mso_rest:
@@ -109,7 +108,6 @@ EXAMPLES = r"""
           displayName: AP2
           epgs: []
         _updateVersion: 0
-  delegate_to: localhost
 
 - name: Add a tenant from a templated payload file from templates
   cisco.mso.mso_rest:
@@ -119,7 +117,6 @@ EXAMPLES = r"""
     method: post
     path: /api/v1/tenants
     content: "{{ lookup('template', 'mso/tenant.json.j2') }}"
-  delegate_to: localhost
 """
 
 RETURN = r"""
