@@ -103,7 +103,6 @@ EXAMPLES = r"""
         operator: in
         value: test
     state: present
-  delegate_to: localhost
 
 - name: Remove a Selector from a site EPG
   cisco.mso.mso_schema_site_anp_epg_selector:
@@ -117,7 +116,6 @@ EXAMPLES = r"""
     epg: EPG 1
     selector: selector_1
     state: absent
-  delegate_to: localhost
 
 - name: Query a specific Selector
   cisco.mso.mso_schema_site_anp_epg_selector:
@@ -131,7 +129,6 @@ EXAMPLES = r"""
     epg: EPG 1
     selector: selector_1
     state: query
-  delegate_to: localhost
   register: query_result
 
 - name: Query all Selectors
@@ -145,7 +142,6 @@ EXAMPLES = r"""
     anp: ANP 1
     epg: EPG 1
     state: query
-  delegate_to: localhost
   register: query_result
 """
 
@@ -234,6 +230,7 @@ def main():
     payload = dict()
     ops = []
     op_path = ""
+    selector_path = None
 
     # Get ANP
     anp_ref = mso.anp_ref(schema_id=schema_id, template=template, anp=anp)
@@ -322,7 +319,7 @@ def main():
 
     mso.previous = mso.existing
     if state == "absent":
-        if mso.existing:
+        if mso.existing and selector_path:
             mso.sent = mso.existing = {}
             ops.append(dict(op="remove", path=selector_path))
     elif state == "present":
@@ -375,7 +372,7 @@ def main():
 
         mso.sanitize(payload, collate=True)
 
-        if mso.existing:
+        if mso.existing and selector_path:
             ops.append(dict(op="replace", path=selector_path, value=mso.sent))
         else:
             ops.append(dict(op="add", path=op_path, value=mso.sent))
