@@ -23,22 +23,22 @@ options:
     description:
     - The name of the schema.
     type: str
-    required: yes
+    required: true
   template:
     description:
     - The name of the template to change.
     type: str
-    required: yes
+    required: true
   external_epg:
     description:
     - The name of the External EPG to be managed.
     type: str
-    required: yes
+    required: true
   site:
     description:
     - The name of the cloud site.
     type: str
-    required: yes
+    required: true
   selector:
     description:
     - The name of the selector.
@@ -94,7 +94,6 @@ EXAMPLES = r"""
         operator: equals
         value: 10.0.0.0
     state: present
-  delegate_to: localhost
 
 - name: Remove a Selector
   cisco.mso.mso_schema_site_external_epg_selector:
@@ -107,7 +106,6 @@ EXAMPLES = r"""
     external_epg: ext1
     selector: test
     state: absent
-  delegate_to: localhost
 
 - name: Query a specific Selector
   cisco.mso.mso_schema_site_external_epg_selector:
@@ -120,7 +118,6 @@ EXAMPLES = r"""
     external_epg: ext1
     selector: selector_1
     state: query
-  delegate_to: localhost
   register: query_result
 
 - name: Query all Selectors
@@ -133,7 +130,6 @@ EXAMPLES = r"""
     site: azure_ansible_test
     external_epg: ext1
     state: query
-  delegate_to: localhost
   register: query_result
 """
 
@@ -202,6 +198,7 @@ def main():
 
     payload = dict()
     op_path = ""
+    selector_path = None
 
     # Get External EPG
     ext_epg_ref = mso.ext_epg_ref(schema_id=schema_id, template=template, external_epg=external_epg)
@@ -241,7 +238,7 @@ def main():
     mso.previous = mso.existing
 
     if state == "absent":
-        if mso.existing:
+        if mso.existing and selector_path:
             mso.sent = mso.existing = {}
             ops.append(dict(op="remove", path=selector_path))
 
@@ -274,7 +271,7 @@ def main():
 
         mso.sanitize(payload, collate=True)
 
-        if mso.existing:
+        if mso.existing and selector_path:
             ops.append(dict(op="replace", path=selector_path, value=mso.sent))
         else:
             ops.append(dict(op="add", path=op_path, value=mso.sent))
