@@ -23,17 +23,17 @@ options:
     description:
     - The name of the schema.
     type: str
-    required: yes
+    required: true
   template:
     description:
     - The name of the template to change.
     type: str
-    required: yes
+    required: true
   bd:
     description:
     - The name of the BD to manage.
     type: str
-    required: yes
+    required: true
   dhcp_policy:
     description:
     - The DHCP Policy
@@ -52,12 +52,12 @@ options:
         description:
         - The name of the DHCP Option Policy.
         type: str
-        required: yes
+        required: true
       version:
         description:
         - The version of the DHCP Option Policy.
         type: int
-        required: yes
+        required: true
   state:
     description:
     - Use C(present) or C(absent) for adding or removing.
@@ -67,6 +67,7 @@ options:
     default: present
 notes:
 - This module can only be used on versions of MSO that are 3.1.1h or greater.
+- This module can only be used on versions of NDO that are 3.7.2i or lower.
 extends_documentation_fragment: cisco.mso.modules
 """
 
@@ -85,7 +86,6 @@ EXAMPLES = r"""
       name: ansible_test_option
       version: 1
     state: present
-  delegate_to: localhost
 
 - name: Remove a DHCP policy from a BD
   cisco.mso.mso_schema_template_bd_dhcp_policy:
@@ -98,7 +98,6 @@ EXAMPLES = r"""
     name: ansible_test
     version: 1
     state: absent
-  delegate_to: localhost
 
 - name: Query a specific BD DHCP Policy
   cisco.mso.mso_schema_template_bd_dhcp_policy:
@@ -110,7 +109,6 @@ EXAMPLES = r"""
     bd: BD 1
     name: ansible_test
     state: query
-  delegate_to: localhost
   register: query_result
 
 - name: Query all BD DHCP Policies
@@ -122,7 +120,6 @@ EXAMPLES = r"""
     template: Template 1
     bd: BD 1
     state: query
-  delegate_to: localhost
   register: query_result
 """
 
