@@ -533,11 +533,11 @@ def create_launch_config(connection, module):
         module.fail_json_aws(e, msg="Failed to connect to AWS")
     try:
         security_groups = get_ec2_security_group_ids_from_names(
-            module.params.get("security_groups"), ec2_connection, vpc_id=vpc_id, boto3=True
+            module.params.get("security_groups"), ec2_connection, vpc_id=vpc_id
         )
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
         module.fail_json_aws(e, msg="Failed to get Security Group IDs")
-    except ValueError as e:
+    except ValueError:
         module.fail_json(msg="Failed to get Security Group IDs", exception=traceback.format_exc())
     user_data = module.params.get("user_data")
     user_data_path = module.params.get("user_data_path")
@@ -571,7 +571,7 @@ def create_launch_config(connection, module):
         try:
             with open(user_data_path, "r") as user_data_file:
                 user_data = user_data_file.read()
-        except IOError as e:
+        except IOError:
             module.fail_json(msg="Failed to open file for reading", exception=traceback.format_exc())
 
     if volumes:
