@@ -144,23 +144,30 @@ EXAMPLES = r"""
 - community.aws.data_pipeline:
   name: test-dp
   objects:
-    - "id": "DefaultSchedule"
-      "name": "Every 1 day"
-      "fields":
+    - id: "DefaultSchedule"
+      name: "Every 1 day"
+      fields:
         - "key": "period"
           "stringValue": "1 days"
         - "key": "type"
           "stringValue": "Schedule"
         - "key": "startAt"
           "stringValue": "FIRST_ACTIVATION_DATE_TIME"
-    - "id": "Default"
-      "name": "Default"
-      "fields": [ { "key": "resourceRole", "stringValue": "my_resource_role" },
-                  { "key": "role", "stringValue": "DataPipelineDefaultRole" },
-                  { "key": "pipelineLogUri", "stringValue": "s3://my_s3_log.txt" },
-                  { "key": "scheduleType", "stringValue": "cron" },
-                  { "key": "schedule", "refValue": "DefaultSchedule" },
-                  { "key": "failureAndRerunMode", "stringValue": "CASCADE" } ]
+    - id: "Default"
+      name: "Default"
+      fields:
+        - "key": "resourceRole"
+          "stringValue": "my_resource_role"
+        - "key": "role"
+          "stringValue": "DataPipelineDefaultRole"
+        - "key": "pipelineLogUri"
+          "stringValue": "s3://my_s3_log.txt"
+        - "key": "scheduleType"
+          "stringValue": "cron"
+        - "key": "schedule"
+          "refValue": "DefaultSchedule"
+        - "key": "failureAndRerunMode"
+          "stringValue": "CASCADE"
   state: active
 
 # Activate pipeline
@@ -174,7 +181,6 @@ EXAMPLES = r"""
     name: test-dp
     region: us-west-2
     state: absent
-
 """
 
 RETURN = r"""
@@ -210,7 +216,6 @@ from ansible_collections.amazon.aws.plugins.module_utils.botocore import is_boto
 
 from ansible_collections.community.aws.plugins.module_utils.modules import AnsibleCommunityAWSModule as AnsibleAWSModule
 
-
 DP_ACTIVE_STATES = ["ACTIVE", "SCHEDULED"]
 DP_INACTIVE_STATES = ["INACTIVE", "PENDING", "FINISHED", "DELETING"]
 DP_ACTIVATING_STATE = "ACTIVATING"
@@ -307,10 +312,7 @@ def check_dp_exists(client, dp_id):
     """
     try:
         # pipeline_description raises DataPipelineNotFound
-        if pipeline_description(client, dp_id):
-            return True
-        else:
-            return False
+        return bool(pipeline_description(client, dp_id))
     except DataPipelineNotFound:
         return False
 
@@ -326,10 +328,7 @@ def check_dp_status(client, dp_id, status):
     """
     if not isinstance(status, list):
         raise AssertionError()
-    if pipeline_field(client, dp_id, field="@pipelineState") in status:
-        return True
-    else:
-        return False
+    return bool(pipeline_field(client, dp_id, field="@pipelineState") in status)
 
 
 def pipeline_status_timeout(client, dp_id, status, timeout):
