@@ -1,32 +1,30 @@
 #!/usr/bin/python
+# -*- coding: utf-8 -*-
+
 # Copyright: Ansible Project
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
-
-
-DOCUMENTATION = '''
+DOCUMENTATION = r"""
 ---
 module: iam_server_certificate_info
 version_added: 1.0.0
 short_description: Retrieve the information of a server certificate
 description:
   - Retrieve the attributes of a server certificate.
-author: "Allen Sanabria (@linuxdynasty)"
+author:
+  - "Allen Sanabria (@linuxdynasty)"
 options:
   name:
     description:
       - The name of the server certificate you are retrieving attributes for.
     type: str
 extends_documentation_fragment:
-- amazon.aws.aws
-- amazon.aws.ec2
-- amazon.aws.boto3
+  - amazon.aws.common.modules
+  - amazon.aws.region.modules
+  - amazon.aws.boto3
+"""
 
-'''
-
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: Retrieve server certificate
   community.aws.iam_server_certificate_info:
     name: production-cert
@@ -37,9 +35,9 @@ EXAMPLES = '''
     name: production-cert
   register: server_cert
   failed_when: "{{ server_cert.results | length == 0 }}"
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 server_certificate_id:
     description: The 21 character certificate id
     returned: success
@@ -75,16 +73,15 @@ upload_date:
     returned: success
     type: str
     sample: "2015-04-25T00:36:40+00:00"
-'''
+"""
 
 
 try:
     import botocore
-    import botocore.exceptions
 except ImportError:
     pass  # Handled by AnsibleAWSModule
 
-from ansible_collections.amazon.aws.plugins.module_utils.core import AnsibleAWSModule
+from ansible_collections.community.aws.plugins.module_utils.modules import AnsibleCommunityAWSModule as AnsibleAWSModule
 
 
 def get_server_certs(iam, name=None):
@@ -113,22 +110,24 @@ def get_server_certs(iam, name=None):
     results = dict()
     try:
         if name:
-            server_certs = [iam.get_server_certificate(ServerCertificateName=name)['ServerCertificate']]
+            server_certs = [iam.get_server_certificate(ServerCertificateName=name)["ServerCertificate"]]
         else:
-            server_certs = iam.list_server_certificates()['ServerCertificateMetadataList']
+            server_certs = iam.list_server_certificates()["ServerCertificateMetadataList"]
 
         for server_cert in server_certs:
             if not name:
-                server_cert = iam.get_server_certificate(ServerCertificateName=server_cert['ServerCertificateName'])['ServerCertificate']
-            cert_md = server_cert['ServerCertificateMetadata']
-            results[cert_md['ServerCertificateName']] = {
-                'certificate_body': server_cert['CertificateBody'],
-                'server_certificate_id': cert_md['ServerCertificateId'],
-                'server_certificate_name': cert_md['ServerCertificateName'],
-                'arn': cert_md['Arn'],
-                'path': cert_md['Path'],
-                'expiration': cert_md['Expiration'].isoformat(),
-                'upload_date': cert_md['UploadDate'].isoformat(),
+                server_cert = iam.get_server_certificate(ServerCertificateName=server_cert["ServerCertificateName"])[
+                    "ServerCertificate"
+                ]
+            cert_md = server_cert["ServerCertificateMetadata"]
+            results[cert_md["ServerCertificateName"]] = {
+                "certificate_body": server_cert["CertificateBody"],
+                "server_certificate_id": cert_md["ServerCertificateId"],
+                "server_certificate_name": cert_md["ServerCertificateName"],
+                "arn": cert_md["Arn"],
+                "path": cert_md["Path"],
+                "expiration": cert_md["Expiration"].isoformat(),
+                "upload_date": cert_md["UploadDate"].isoformat(),
             }
 
     except botocore.exceptions.ClientError:
@@ -139,7 +138,7 @@ def get_server_certs(iam, name=None):
 
 def main():
     argument_spec = dict(
-        name=dict(type='str'),
+        name=dict(type="str"),
     )
 
     module = AnsibleAWSModule(
@@ -148,14 +147,14 @@ def main():
     )
 
     try:
-        iam = module.client('iam')
+        iam = module.client("iam")
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, msg='Failed to connect to AWS')
+        module.fail_json_aws(e, msg="Failed to connect to AWS")
 
-    cert_name = module.params.get('name')
+    cert_name = module.params.get("name")
     results = get_server_certs(iam, cert_name)
     module.exit_json(results=results)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
