@@ -287,7 +287,7 @@ resources:
 """
 
 import time
-from ansible.module_utils.basic import AnsibleModule, env_fallback
+from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.digitalocean.plugins.module_utils.digital_ocean import (
     DigitalOceanHelper,
     DigitalOceanProjects,
@@ -319,7 +319,7 @@ class DODroplet(object):
         self.name = None
         self.size = None
         self.status = None
-        if self.module.params.get("project"):
+        if self.module.params.get("project_name"):
             # only load for non-default project assignments
             self.projects = DigitalOceanProjects(module, self.rest)
         self.firewalls = self.get_firewalls()
@@ -621,6 +621,17 @@ class DODroplet(object):
         json_data = response.json
         status_code = response.status_code
         message = json_data.get("message", "no error message")
+
+        # action and other fields may not be available in case of error, check first
+        # will catch Not Authorized due to restrictive Scopes
+        if status_code >= 400:
+            self.module.fail_json(
+                changed=False,
+                msg=DODroplet.failure_message["failed_to"].format(
+                    "post", "action", status_code, message
+                ),
+            )
+
         action = json_data.get("action", None)
         action_id = action.get("id", None)
         action_status = action.get("status", None)
@@ -633,14 +644,6 @@ class DODroplet(object):
                 ),
             )
 
-        if status_code >= 400:
-            self.module.fail_json(
-                changed=False,
-                msg=DODroplet.failure_message["failed_to"].format(
-                    "post", "action", status_code, message
-                ),
-            )
-
         # Keep checking till it is done or times out
         self.wait_check_action(droplet_id, action_id)
 
@@ -779,7 +782,7 @@ class DODroplet(object):
             if json_data:
                 droplet = json_data.get("droplet", droplet)
 
-        project_name = self.module.params.get("project")
+        project_name = self.module.params.get("project_name")
         if project_name:  # empty string is the default project, skip project assignment
             urn = "do:droplet:{0}".format(droplet_id)
             assign_status, error_message, resources = self.projects.assign_to_project(
